<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:json="http://json.org/">
  <!-- from https://gist.github.com/inancgumus/3ce56ddde6d5c93f3550b3b4cdc6bcb8 -->
  <!-- https://github.com/bramstein/xsltjson/blob/master/conf/xml-to-jsonml.xsl -->
  <xsl:output method="text" omit-xml-declaration="yes" encoding="utf-8"/>

  <xsl:template match="/*[node()]">
    <xsl:apply-templates select="." mode="obj-list" />
  </xsl:template>

  <xsl:template match="*" mode="detect">
    <xsl:choose>
      <xsl:when test="count(./child::*) > 0 or count(@*) > 0">
        <xsl:text>"</xsl:text><xsl:value-of select="name()"/>" : <xsl:apply-templates select="." mode="obj-content" />
      </xsl:when>
      <xsl:when test="count(./child::*) = 0">
        <xsl:text>"</xsl:text><xsl:value-of select="name()"/>" : <xsl:apply-templates select="." mode="value"/>
      </xsl:when>
    </xsl:choose>
    <xsl:if test="count(following-sibling::*) &gt; 0">, </xsl:if>
  </xsl:template>

  <xsl:template match="*" mode="value">
    <xsl:text>"</xsl:text><xsl:apply-templates select="."/><xsl:text>"</xsl:text>
  </xsl:template>

  <xsl:template match="*" mode="obj-detect">
    {
    <xsl:choose>
      <xsl:when test="count(./child::*) > 0 or count(@*) > 0">
        <xsl:text>"</xsl:text><xsl:value-of select="name()"/>" : <xsl:apply-templates select="." mode="obj-content" />
      </xsl:when>
      <xsl:when test="count(./child::*) = 0">
        <xsl:text>"</xsl:text><xsl:value-of select="name()"/>" : <xsl:apply-templates select="." mode="value"/>
      </xsl:when>
    </xsl:choose>
    }
  </xsl:template>

  <!-- objects -->
  <xsl:template match="Activity | AggregateCharacteristicInfo | AggregateStatisticFact | AggregateStatisticInfo | CalendarDate | CalendarSummary | EquipmentInfo | GradingAssignment | GradingAssignmentScore | Identity | LEAInfo | LearningResource | LearningResourcePackage | LearningStandardDocument | LearningStandardItem | MarkValueInfo | PersonPicture | PersonPrivacyObligation | PersonalisedPlan | ReportAuthorityInfo | ResourceBooking | ResourceUsage | RoomInfo | ScheduledActivity | SchoolCourseInfo | SchoolInfo | SchoolPrograms | SectionInfo | SessionInfo | StaffAssignment | StaffPersonal | StudentActivityInfo | StudentActivityParticipation | StudentAttendanceSummary | StudentAttendanceTimeList | StudentContactPersonal | StudentContactRelationship | StudentDailyAttendance | StudentGrade | StudentParticipation | StudentPeriodAttendance | StudentPersonal | StudentSchoolEnrollment | StudentSectionEnrollment | SystemRole | TeachingGroup | TermInfo | TimeTable | TimeTableCell | TimeTableSubject | WellbeingAlert | WellbeingAppeal | WellbeingCharacteristic | WellbeingEvent | WellbeingResponse | AGStatusReport | ChargedLocationInfo | Debtor | FQReporting | FinancialAccount | Invoice | Journal | NAPCodeFrame | NAPEventStudentLink | NAPStudentResponseSet | NAPTest | NAPTestItem | NAPTestScoreSummary | NAPTestlet | PaymentReceipt | PurchaseOrder | VendorInfo" mode="obj-list">
    <xsl:if test="count(preceding-sibling::*) = 0">
      <xsl:text>[</xsl:text>
    </xsl:if>
    <xsl:choose>
      <xsl:when test="count(./child::*) > 0 or count(@*) > 0">
        <xsl:apply-templates select="." mode="obj-detect" />
      </xsl:when>
    </xsl:choose>
    <xsl:if test="count(following-sibling::*) &gt; 0">, </xsl:if>
    <xsl:if test="count(following-sibling::*) = 0"><xsl:text>]</xsl:text></xsl:if>
  </xsl:template>

  <!-- numeric or boolean -->
  <xsl:template match="Activity/Points | Activity/ActivityTime/Duration | Activity/MaxAttemptsAllowed | Activity/ActivityWeight | AggregateStatisticFact/Value | CalendarDate/CalendarDateNumber | CalendarDate/StudentAttendance/AttendanceValue | CalendarDate/TeacherAttendance/AttendanceValue | CalendarDate/AdministratorAttendance/AttendanceValue | CalendarSummary/DaysInSession | CalendarSummary/InstructionalMinutes | CalendarSummary/MinutesPerDay | GradingAssignment/PointsPossible | GradingAssignment/Weight | GradingAssignment/MaxAttemptsAllowed | GradingAssignment/RubricScoringGuide/ScoreList/Score/MaxScoreValue | GradingAssignment/RubricScoringGuide/ScoreList/Score/ScoreDescriptionList/ScoreDescription/ScoreValue | GradingAssignmentScore/ScorePoints | GradingAssignmentScore/ScorePercent | GradingAssignmentScore/SubscoreList/Subscore/SubscoreValue | LEAInfo/LEAContactList/LEAContact/ContactInfo/Address/GridLocation/Latitude | LEAInfo/LEAContactList/LEAContact/ContactInfo/Address/GridLocation/Longitude | LEAInfo/LEAContactList/LEAContact/ContactInfo/PhoneNumberList/PhoneNumber/Preference | LEAInfo/PhoneNumberList/PhoneNumber/Preference | LEAInfo/AddressList/Address/GridLocation/Latitude | LEAInfo/AddressList/Address/GridLocation/Longitude | LearningResource/Contacts/Contact/Address/GridLocation/Latitude | LearningResource/Contacts/Contact/Address/GridLocation/Longitude | LearningResource/Contacts/Contact/PhoneNumber/Preference | LearningStandardItem/StandardHierarchyLevel/Number | MarkValueInfo/PercentageMinimum | MarkValueInfo/PercentageMaximum | MarkValueInfo/PercentagePassingGrade | MarkValueInfo/NumericPrecision | MarkValueInfo/NumericScale | MarkValueInfo/NumericLow | MarkValueInfo/NumericHigh | MarkValueInfo/NumericPassingGrade | MarkValueInfo/ValidLetterMarkList/ValidLetterMark/NumericEquivalent | MarkValueInfo/NarrativeMaximumSize | ReportAuthorityInfo/ContactInfo/Address/GridLocation/Latitude | ReportAuthorityInfo/ContactInfo/Address/GridLocation/Longitude | ReportAuthorityInfo/ContactInfo/PhoneNumberList/PhoneNumber/Preference | ReportAuthorityInfo/Address/GridLocation/Latitude | ReportAuthorityInfo/Address/GridLocation/Longitude | ReportAuthorityInfo/PhoneNumber/Preference | ResourceUsage/ResourceReportLineList/ResourceReportLine/CurrentCost | RoomInfo/Size | RoomInfo/Capacity | RoomInfo/PhoneNumber/Preference | ScheduledActivity/TeacherList/TeacherCover/Weighting | ScheduledActivity/AddressList/Address/GridLocation/Latitude | ScheduledActivity/AddressList/Address/GridLocation/Longitude | SchoolInfo/PrincipalInfo/PhoneNumberList/PhoneNumber/Preference | SchoolInfo/SchoolContactList/SchoolContact/ContactInfo/Address/GridLocation/Latitude | SchoolInfo/SchoolContactList/SchoolContact/ContactInfo/Address/GridLocation/Longitude | SchoolInfo/SchoolContactList/SchoolContact/ContactInfo/PhoneNumberList/PhoneNumber/Preference | SchoolInfo/AddressList/Address/GridLocation/Latitude | SchoolInfo/AddressList/Address/GridLocation/Longitude | SchoolInfo/PhoneNumberList/PhoneNumber/Preference | SchoolInfo/ARIA | StaffAssignment/JobFTE | StaffAssignment/StaffSubjectList/StaffSubject/PreferenceNumber | StaffPersonal/PersonInfo/AddressList/Address/GridLocation/Latitude | StaffPersonal/PersonInfo/AddressList/Address/GridLocation/Longitude | StaffPersonal/PersonInfo/PhoneNumberList/PhoneNumber/Preference | StaffPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/PreferenceNumber | StaffPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/AddressList/Address/GridLocation/Latitude | StaffPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/AddressList/Address/GridLocation/Longitude | StaffPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/PhoneNumberList/PhoneNumber/Preference | StudentAttendanceSummary/StartDay | StudentAttendanceSummary/EndDay | StudentAttendanceSummary/FTE | StudentAttendanceSummary/DaysAttended | StudentAttendanceSummary/ExcusedAbsences | StudentAttendanceSummary/UnexcusedAbsences | StudentAttendanceSummary/DaysTardy | StudentAttendanceSummary/DaysInMembership | StudentAttendanceTimeList/AttendanceTimes/AttendanceTime/DurationValue | StudentAttendanceTimeList/PeriodAttendances/PeriodAttendance/TeacherList/TeacherCover/Weighting | StudentContactPersonal/PersonInfo/AddressList/Address/GridLocation/Latitude | StudentContactPersonal/PersonInfo/AddressList/Address/GridLocation/Longitude | StudentContactPersonal/PersonInfo/PhoneNumberList/PhoneNumber/Preference | StudentContactPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/PreferenceNumber | StudentContactPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/AddressList/Address/GridLocation/Latitude | StudentContactPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/AddressList/Address/GridLocation/Longitude | StudentContactPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/PhoneNumberList/PhoneNumber/Preference | StudentContactRelationship/ContactSequence | StudentDailyAttendance/AbsenceValue | StudentGrade/GradingScoreList/GradingAssignmentScore/Weight | StudentGrade/Grade/Percentage | StudentGrade/Grade/Numeric | StudentParticipation/StudentSpecialEducationFTE | StudentPersonal/PersonInfo/AddressList/Address/GridLocation/Latitude | StudentPersonal/PersonInfo/AddressList/Address/GridLocation/Longitude | StudentPersonal/PersonInfo/PhoneNumberList/PhoneNumber/Preference | StudentPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/PreferenceNumber | StudentPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/AddressList/Address/GridLocation/Latitude | StudentPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/AddressList/Address/GridLocation/Longitude | StudentPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/PhoneNumberList/PhoneNumber/Preference | StudentPersonal/MostRecent/FTE | StudentSchoolEnrollment/FTE | StudentSchoolEnrollment/StudentSubjectChoiceList/StudentSubjectChoice/PreferenceNumber | TeachingGroup/Semester | TeachingGroup/MinClassSize | TeachingGroup/MaxClassSize | TermInfo/RelativeDuration | TimeTable/DaysPerCycle | TimeTable/PeriodsPerDay | TimeTable/TeachingPeriodsPerDay | TimeTable/TimeTableDayList/TimeTableDay/TimeTablePeriodList/TimeTablePeriod/InstructionalMinutes | TimeTableCell/TeacherList/TeacherCover/Weighting | TimeTableSubject/ProposedMaxClassSize | TimeTableSubject/ProposedMinClassSize | TimeTableSubject/Semester | WellbeingResponse/Suspension/Duration | ChargedLocationInfo/AddressList/Address/GridLocation/Latitude | ChargedLocationInfo/AddressList/Address/GridLocation/Longitude | ChargedLocationInfo/PhoneNumberList/PhoneNumber/Preference | Debtor/AddressList/Address/GridLocation/Latitude | Debtor/AddressList/Address/GridLocation/Longitude | FQReporting/EntityContact/Address/GridLocation/Latitude | FQReporting/EntityContact/Address/GridLocation/Longitude | FQReporting/EntityContact/PhoneNumber/Preference | FQReporting/FQItemList/FQItem/TuitionAmount | FQReporting/FQItemList/FQItem/BoardingAmount | FQReporting/FQItemList/FQItem/SystemAmount | FQReporting/FQItemList/FQItem/DioceseAmount | Invoice/NetAmount | Invoice/TaxRate | Invoice/TaxAmount | Invoice/PurchasingItems/PurchasingItem/UnitCost | Invoice/PurchasingItems/PurchasingItem/TotalCost | Invoice/PurchasingItems/PurchasingItem/TaxRate | Invoice/PurchasingItems/PurchasingItem/ExpenseAccounts/ExpenseAccount/Amount | Journal/Amount | NAPCodeFrame/TestContent/StagesCount | NAPCodeFrame/TestContent/DomainBands/Band1Lower | NAPCodeFrame/TestContent/DomainBands/Band1Upper | NAPCodeFrame/TestContent/DomainBands/Band2Lower | NAPCodeFrame/TestContent/DomainBands/Band2Upper | NAPCodeFrame/TestContent/DomainBands/Band3Lower | NAPCodeFrame/TestContent/DomainBands/Band3Upper | NAPCodeFrame/TestContent/DomainBands/Band4Lower | NAPCodeFrame/TestContent/DomainBands/Band4Upper | NAPCodeFrame/TestContent/DomainBands/Band5Lower | NAPCodeFrame/TestContent/DomainBands/Band5Upper | NAPCodeFrame/TestContent/DomainBands/Band6Lower | NAPCodeFrame/TestContent/DomainBands/Band6Upper | NAPCodeFrame/TestContent/DomainBands/Band7Lower | NAPCodeFrame/TestContent/DomainBands/Band7Upper | NAPCodeFrame/TestContent/DomainBands/Band8Lower | NAPCodeFrame/TestContent/DomainBands/Band8Upper | NAPCodeFrame/TestContent/DomainBands/Band9Lower | NAPCodeFrame/TestContent/DomainBands/Band9Upper | NAPCodeFrame/TestContent/DomainBands/Band10Lower | NAPCodeFrame/TestContent/DomainBands/Band10Upper | NAPCodeFrame/TestContent/DomainProficiency/Level1Lower | NAPCodeFrame/TestContent/DomainProficiency/Level1Upper | NAPCodeFrame/TestContent/DomainProficiency/Level2Lower | NAPCodeFrame/TestContent/DomainProficiency/Level2Upper | NAPCodeFrame/TestContent/DomainProficiency/Level3Lower | NAPCodeFrame/TestContent/DomainProficiency/Level3Upper | NAPCodeFrame/TestContent/DomainProficiency/Level4Lower | NAPCodeFrame/TestContent/DomainProficiency/Level4Upper | NAPCodeFrame/TestletList/Testlet/TestletContent/LocationInStage | NAPCodeFrame/TestletList/Testlet/TestletContent/TestletMaximumScore | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem/SequenceNumber | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem/TestItemContent/MultipleChoiceOptionCount | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem/TestItemContent/MaximumScore | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem/TestItemContent/ItemDifficulty | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem/TestItemContent/ItemDifficultyLogit5 | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem/TestItemContent/ItemDifficultyLogit62 | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem/TestItemContent/ItemDifficultyLogit5SE | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem/TestItemContent/ItemDifficultyLogit62SE | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem/TestItemContent/ItemProficiencyBand | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem/TestItemContent/StimulusList/Stimulus/WordCount | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem/TestItemContent/NAPWritingRubricList/NAPWritingRubric/ScoreList/Score/MaxScoreValue | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem/TestItemContent/NAPWritingRubricList/NAPWritingRubric/ScoreList/Score/ScoreDescriptionList/ScoreDescription/ScoreValue | NAPStudentResponseSet/DomainScore/RawScore | NAPStudentResponseSet/DomainScore/ScaledScoreValue | NAPStudentResponseSet/DomainScore/ScaledScoreLogitValue | NAPStudentResponseSet/DomainScore/ScaledScoreStandardError | NAPStudentResponseSet/DomainScore/ScaledScoreLogitStandardError | NAPStudentResponseSet/DomainScore/StudentDomainBand | NAPStudentResponseSet/DomainScore/PlausibleScaledValueList/PlausibleScaledValue | NAPStudentResponseSet/TestletList/Testlet/TestletSubScore | NAPStudentResponseSet/TestletList/Testlet/ItemResponseList/ItemResponse/Score | NAPStudentResponseSet/TestletList/Testlet/ItemResponseList/ItemResponse/SequenceNumber | NAPStudentResponseSet/TestletList/Testlet/ItemResponseList/ItemResponse/ItemWeight | NAPStudentResponseSet/TestletList/Testlet/ItemResponseList/ItemResponse/SubscoreList/Subscore/SubscoreValue | NAPTest/TestContent/StagesCount | NAPTest/TestContent/DomainBands/Band1Lower | NAPTest/TestContent/DomainBands/Band1Upper | NAPTest/TestContent/DomainBands/Band2Lower | NAPTest/TestContent/DomainBands/Band2Upper | NAPTest/TestContent/DomainBands/Band3Lower | NAPTest/TestContent/DomainBands/Band3Upper | NAPTest/TestContent/DomainBands/Band4Lower | NAPTest/TestContent/DomainBands/Band4Upper | NAPTest/TestContent/DomainBands/Band5Lower | NAPTest/TestContent/DomainBands/Band5Upper | NAPTest/TestContent/DomainBands/Band6Lower | NAPTest/TestContent/DomainBands/Band6Upper | NAPTest/TestContent/DomainBands/Band7Lower | NAPTest/TestContent/DomainBands/Band7Upper | NAPTest/TestContent/DomainBands/Band8Lower | NAPTest/TestContent/DomainBands/Band8Upper | NAPTest/TestContent/DomainBands/Band9Lower | NAPTest/TestContent/DomainBands/Band9Upper | NAPTest/TestContent/DomainBands/Band10Lower | NAPTest/TestContent/DomainBands/Band10Upper | NAPTest/TestContent/DomainProficiency/Level1Lower | NAPTest/TestContent/DomainProficiency/Level1Upper | NAPTest/TestContent/DomainProficiency/Level2Lower | NAPTest/TestContent/DomainProficiency/Level2Upper | NAPTest/TestContent/DomainProficiency/Level3Lower | NAPTest/TestContent/DomainProficiency/Level3Upper | NAPTest/TestContent/DomainProficiency/Level4Lower | NAPTest/TestContent/DomainProficiency/Level4Upper | NAPTestItem/TestItemContent/MultipleChoiceOptionCount | NAPTestItem/TestItemContent/MaximumScore | NAPTestItem/TestItemContent/ItemDifficulty | NAPTestItem/TestItemContent/ItemDifficultyLogit5 | NAPTestItem/TestItemContent/ItemDifficultyLogit62 | NAPTestItem/TestItemContent/ItemDifficultyLogit5SE | NAPTestItem/TestItemContent/ItemDifficultyLogit62SE | NAPTestItem/TestItemContent/ItemProficiencyBand | NAPTestItem/TestItemContent/StimulusList/Stimulus/WordCount | NAPTestItem/TestItemContent/NAPWritingRubricList/NAPWritingRubric/ScoreList/Score/MaxScoreValue | NAPTestItem/TestItemContent/NAPWritingRubricList/NAPWritingRubric/ScoreList/Score/ScoreDescriptionList/ScoreDescription/ScoreValue | NAPTestScoreSummary/DomainNationalAverage | NAPTestScoreSummary/DomainSchoolAverage | NAPTestScoreSummary/DomainJurisdictionAverage | NAPTestScoreSummary/DomainTopNational60Percent | NAPTestScoreSummary/DomainBottomNational60Percent | NAPTestlet/TestletContent/LocationInStage | NAPTestlet/TestletContent/TestletMaximumScore | NAPTestlet/TestItemList/TestItem/SequenceNumber | PaymentReceipt/TaxRate | PaymentReceipt/TaxAmount | PurchaseOrder/PurchasingItems/PurchasingItem/UnitCost | PurchaseOrder/PurchasingItems/PurchasingItem/TotalCost | PurchaseOrder/PurchasingItems/PurchasingItem/TaxRate | PurchaseOrder/PurchasingItems/PurchasingItem/ExpenseAccounts/ExpenseAccount/Amount | PurchaseOrder/TaxRate | PurchaseOrder/TaxAmount | PurchaseOrder/TotalAmount | VendorInfo/ContactInfo/Address/GridLocation/Latitude | VendorInfo/ContactInfo/Address/GridLocation/Longitude | VendorInfo/ContactInfo/PhoneNumberList/PhoneNumber/Preference" mode="value">
    <xsl:apply-templates select="."/>
  </xsl:template>

  <xsl:template match="* | @*" mode="attrvalue">
    <xsl:text>"</xsl:text><xsl:apply-templates select="."/><xsl:text>"</xsl:text>
  </xsl:template>

  <!-- numeric or boolean attribute -->
  <xsl:template match="NEVERMATCH" mode="attrvalue">
    <xsl:apply-templates select="."/>
  </xsl:template>

  <!-- simple content with attribute -->
  <xsl:template match="Activity/SubjectArea/OtherCodeList/OtherCode | Activity/SourceObjects/SourceObject | Activity/ActivityTime/Duration | Activity/SIF_ExtendedElements/SIF_ExtendedElement | AggregateCharacteristicInfo/SIF_ExtendedElements/SIF_ExtendedElement | AggregateStatisticFact/SIF_ExtendedElements/SIF_ExtendedElement | AggregateStatisticInfo/CalculationRule | AggregateStatisticInfo/ExclusionRules/ExclusionRule | AggregateStatisticInfo/Location/LocationRefId | AggregateStatisticInfo/SIF_ExtendedElements/SIF_ExtendedElement | CalendarDate/CalendarDateType/OtherCodeList/OtherCode | CalendarDate/SIF_ExtendedElements/SIF_ExtendedElement | CalendarSummary/SIF_ExtendedElements/SIF_ExtendedElement | EquipmentInfo/SIF_RefId | EquipmentInfo/SIF_ExtendedElements/SIF_ExtendedElement | GradingAssignment/SIF_ExtendedElements/SIF_ExtendedElement | GradingAssignmentScore/SIF_ExtendedElements/SIF_ExtendedElement | Identity/SIF_RefId | Identity/IdentityAssertions/IdentityAssertion | Identity/PasswordList/Password | Identity/SIF_ExtendedElements/SIF_ExtendedElement | LEAInfo/EducationAgencyType/OtherCodeList/OtherCode | LEAInfo/LEAContactList/LEAContact/ContactInfo/Address/StatisticalAreas/StatisticalArea | LEAInfo/LEAContactList/LEAContact/ContactInfo/EmailList/Email | LEAInfo/AddressList/Address/StatisticalAreas/StatisticalArea | LEAInfo/SIF_ExtendedElements/SIF_ExtendedElement | LearningResource/Contacts/Contact/Address/StatisticalAreas/StatisticalArea | LearningResource/Contacts/Contact/Email | LearningResource/Location | LearningResource/SubjectAreas/ACStrandSubjectArea/SubjectArea/OtherCodeList/OtherCode | LearningResource/Components/Component/AssociatedObjects/AssociatedObject | LearningResource/SIF_ExtendedElements/SIF_ExtendedElement | LearningStandardDocument/RichDescription/XMLData | LearningStandardDocument/RichDescription/TextData | LearningStandardDocument/RichDescription/BinaryData | LearningStandardDocument/SubjectAreas/ACStrandSubjectArea/SubjectArea/OtherCodeList/OtherCode | LearningStandardDocument/SIF_ExtendedElements/SIF_ExtendedElement | LearningStandardItem/Resources/LearningResourceRefId | LearningStandardItem/ACStrandSubjectArea/SubjectArea/OtherCodeList/OtherCode | LearningStandardItem/StandardIdentifier/ACStrandSubjectArea/SubjectArea/OtherCodeList/OtherCode | LearningStandardItem/RelatedLearningStandardItems/LearningStandardItemRefId | LearningStandardItem/SIF_ExtendedElements/SIF_ExtendedElement | MarkValueInfo/SIF_ExtendedElements/SIF_ExtendedElement | PersonPicture/ParentObjectRefId | PersonPicture/PictureSource | PersonPicture/SIF_ExtendedElements/SIF_ExtendedElement | PersonPrivacyObligation/SIF_ExtendedElements/SIF_ExtendedElement | PersonalisedPlan/SIF_ExtendedElements/SIF_ExtendedElement | ReportAuthorityInfo/ContactInfo/Address/StatisticalAreas/StatisticalArea | ReportAuthorityInfo/ContactInfo/EmailList/Email | ReportAuthorityInfo/Address/StatisticalAreas/StatisticalArea | ReportAuthorityInfo/SIF_ExtendedElements/SIF_ExtendedElement | ResourceBooking/ResourceRefId | ResourceBooking/SIF_ExtendedElements/SIF_ExtendedElement | ResourceUsage/ResourceReportLineList/ResourceReportLine/SIF_RefId | ResourceUsage/ResourceReportLineList/ResourceReportLine/CurrentCost | ResourceUsage/SIF_ExtendedElements/SIF_ExtendedElement | RoomInfo/SIF_ExtendedElements/SIF_ExtendedElement | ScheduledActivity/AddressList/Address/StatisticalAreas/StatisticalArea | ScheduledActivity/Override | ScheduledActivity/SIF_ExtendedElements/SIF_ExtendedElement | SchoolCourseInfo/SubjectAreaList/SubjectArea/OtherCodeList/OtherCode | SchoolCourseInfo/SIF_ExtendedElements/SIF_ExtendedElement | SchoolInfo/OtherIdList/OtherId | SchoolInfo/OtherLEA | SchoolInfo/SchoolEmailList/Email | SchoolInfo/PrincipalInfo/EmailList/Email | SchoolInfo/SchoolContactList/SchoolContact/ContactInfo/Address/StatisticalAreas/StatisticalArea | SchoolInfo/SchoolContactList/SchoolContact/ContactInfo/EmailList/Email | SchoolInfo/AddressList/Address/StatisticalAreas/StatisticalArea | SchoolInfo/SIF_ExtendedElements/SIF_ExtendedElement | SchoolPrograms/SchoolProgramList/Program/OtherCodeList/OtherCode | SchoolPrograms/SIF_ExtendedElements/SIF_ExtendedElement | SectionInfo/MediumOfInstruction/OtherCodeList/OtherCode | SectionInfo/LanguageOfInstruction/OtherCodeList/OtherCode | SectionInfo/LocationOfInstruction/OtherCodeList/OtherCode | SectionInfo/SchoolCourseInfoOverride/SubjectArea/OtherCodeList/OtherCode | SectionInfo/SIF_ExtendedElements/SIF_ExtendedElement | SessionInfo/SIF_ExtendedElements/SIF_ExtendedElement | StaffAssignment/StaffActivity/OtherCodeList/OtherCode | StaffAssignment/SIF_ExtendedElements/SIF_ExtendedElement | StaffPersonal/ElectronicIdList/ElectronicId | StaffPersonal/OtherIdList/OtherId | StaffPersonal/PersonInfo/Demographics/EnglishProficiency/OtherCodeList/OtherCode | StaffPersonal/PersonInfo/Demographics/LanguageList/Language/OtherCodeList/OtherCode | StaffPersonal/PersonInfo/Demographics/DwellingArrangement/OtherCodeList/OtherCode | StaffPersonal/PersonInfo/Demographics/Religion/OtherCodeList/OtherCode | StaffPersonal/PersonInfo/AddressList/Address/StatisticalAreas/StatisticalArea | StaffPersonal/PersonInfo/EmailList/Email | StaffPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/AddressList/Address/StatisticalAreas/StatisticalArea | StaffPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/EmailList/Email | StaffPersonal/SIF_ExtendedElements/SIF_ExtendedElement | StudentActivityInfo/StudentActivityType/OtherCodeList/OtherCode | StudentActivityInfo/Location/LocationRefId | StudentActivityInfo/SIF_ExtendedElements/SIF_ExtendedElement | StudentActivityParticipation/SIF_ExtendedElements/SIF_ExtendedElement | StudentAttendanceSummary/SIF_ExtendedElements/SIF_ExtendedElement | StudentAttendanceTimeList/AttendanceTimes/AttendanceTime/AttendanceCode/OtherCodeList/OtherCode | StudentAttendanceTimeList/PeriodAttendances/PeriodAttendance/AttendanceCode/OtherCodeList/OtherCode | StudentAttendanceTimeList/SIF_ExtendedElements/SIF_ExtendedElement | StudentContactPersonal/OtherIdList/OtherId | StudentContactPersonal/PersonInfo/Demographics/EnglishProficiency/OtherCodeList/OtherCode | StudentContactPersonal/PersonInfo/Demographics/LanguageList/Language/OtherCodeList/OtherCode | StudentContactPersonal/PersonInfo/Demographics/DwellingArrangement/OtherCodeList/OtherCode | StudentContactPersonal/PersonInfo/Demographics/Religion/OtherCodeList/OtherCode | StudentContactPersonal/PersonInfo/AddressList/Address/StatisticalAreas/StatisticalArea | StudentContactPersonal/PersonInfo/EmailList/Email | StudentContactPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/AddressList/Address/StatisticalAreas/StatisticalArea | StudentContactPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/EmailList/Email | StudentContactPersonal/SIF_ExtendedElements/SIF_ExtendedElement | StudentContactRelationship/Relationship/OtherCodeList/OtherCode | StudentContactRelationship/SIF_ExtendedElements/SIF_ExtendedElement | StudentDailyAttendance/AttendanceCode/OtherCodeList/OtherCode | StudentDailyAttendance/SIF_ExtendedElements/SIF_ExtendedElement | StudentGrade/LearningArea/SubjectArea/OtherCodeList/OtherCode | StudentGrade/SIF_ExtendedElements/SIF_ExtendedElement | StudentParticipation/ProgramFundingSources/ProgramFundingSource/OtherCodeList/OtherCode | StudentParticipation/ManagingSchool | StudentParticipation/ReferralSource/OtherCodeList/OtherCode | StudentParticipation/ProgramStatus/OtherCodeList/OtherCode | StudentParticipation/ProgramAvailability/OtherCodeList/OtherCode | StudentParticipation/SIF_ExtendedElements/SIF_ExtendedElement | StudentPeriodAttendance/AttendanceCode/OtherCodeList/OtherCode | StudentPeriodAttendance/SIF_ExtendedElements/SIF_ExtendedElement | StudentPersonal/AlertMessages/AlertMessage | StudentPersonal/MedicalAlertMessages/MedicalAlertMessage | StudentPersonal/ElectronicIdList/ElectronicId | StudentPersonal/OtherIdList/OtherId | StudentPersonal/PersonInfo/Demographics/EnglishProficiency/OtherCodeList/OtherCode | StudentPersonal/PersonInfo/Demographics/LanguageList/Language/OtherCodeList/OtherCode | StudentPersonal/PersonInfo/Demographics/DwellingArrangement/OtherCodeList/OtherCode | StudentPersonal/PersonInfo/Demographics/Religion/OtherCodeList/OtherCode | StudentPersonal/PersonInfo/AddressList/Address/StatisticalAreas/StatisticalArea | StudentPersonal/PersonInfo/EmailList/Email | StudentPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/AddressList/Address/StatisticalAreas/StatisticalArea | StudentPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/EmailList/Email | StudentPersonal/SIF_ExtendedElements/SIF_ExtendedElement | StudentSchoolEnrollment/EntryType/OtherCodeList/OtherCode | StudentSchoolEnrollment/Homeroom | StudentSchoolEnrollment/Advisor | StudentSchoolEnrollment/Counselor | StudentSchoolEnrollment/Calendar | StudentSchoolEnrollment/ExitStatus/OtherCodeList/OtherCode | StudentSchoolEnrollment/ExitType/OtherCodeList/OtherCode | StudentSchoolEnrollment/CatchmentStatus/OtherCodeList/OtherCode | StudentSchoolEnrollment/StudentSubjectChoiceList/StudentSubjectChoice/StudyDescription/OtherCodeList/OtherCode | StudentSchoolEnrollment/SIF_ExtendedElements/SIF_ExtendedElement | StudentSectionEnrollment/SIF_ExtendedElements/SIF_ExtendedElement | SystemRole/SIF_RefId | SystemRole/SystemContextList/SystemContext/RoleList/Role/RoleScopeList/RoleScope/RoleScopeRefId | SystemRole/SIF_ExtendedElements/SIF_ExtendedElement | TeachingGroup/SIF_ExtendedElements/SIF_ExtendedElement | TermInfo/SIF_ExtendedElements/SIF_ExtendedElement | TimeTable/SIF_ExtendedElements/SIF_ExtendedElement | TimeTableCell/SIF_ExtendedElements/SIF_ExtendedElement | TimeTableSubject/OtherCodeList/OtherCode | TimeTableSubject/SIF_ExtendedElements/SIF_ExtendedElement | WellbeingAlert/SIF_ExtendedElements/SIF_ExtendedElement | WellbeingAppeal/SIF_ExtendedElements/SIF_ExtendedElement | WellbeingCharacteristic/SIF_ExtendedElements/SIF_ExtendedElement | WellbeingEvent/PersonInvolvementList/PersonInvolvement/PersonRefId | WellbeingEvent/SIF_ExtendedElements/SIF_ExtendedElement | WellbeingResponse/PersonInvolvementList/PersonInvolvement/PersonRefId | WellbeingResponse/SIF_ExtendedElements/SIF_ExtendedElement | AGStatusReport/SIF_ExtendedElements/SIF_ExtendedElement | ChargedLocationInfo/AddressList/Address/StatisticalAreas/StatisticalArea | ChargedLocationInfo/SIF_ExtendedElements/SIF_ExtendedElement | Debtor/BilledEntity | Debtor/AddressList/Address/StatisticalAreas/StatisticalArea | Debtor/SIF_ExtendedElements/SIF_ExtendedElement | FQReporting/EntityContact/Address/StatisticalAreas/StatisticalArea | FQReporting/EntityContact/Email | FQReporting/SIF_ExtendedElements/SIF_ExtendedElement | FinancialAccount/SIF_ExtendedElements/SIF_ExtendedElement | Invoice/InvoicedEntity | Invoice/BilledAmount | Invoice/NetAmount | Invoice/TaxAmount | Invoice/PurchasingItems/PurchasingItem/UnitCost | Invoice/PurchasingItems/PurchasingItem/TotalCost | Invoice/PurchasingItems/PurchasingItem/ExpenseAccounts/ExpenseAccount/Amount | Invoice/SIF_ExtendedElements/SIF_ExtendedElement | Journal/OriginatingTransactionRefId | Journal/Amount | Journal/SIF_ExtendedElements/SIF_ExtendedElement | NAPCodeFrame/SIF_ExtendedElements/SIF_ExtendedElement | NAPEventStudentLink/SIF_ExtendedElements/SIF_ExtendedElement | NAPStudentResponseSet/SIF_ExtendedElements/SIF_ExtendedElement | NAPTest/SIF_ExtendedElements/SIF_ExtendedElement | NAPTestItem/SIF_ExtendedElements/SIF_ExtendedElement | NAPTestScoreSummary/SIF_ExtendedElements/SIF_ExtendedElement | NAPTestlet/SIF_ExtendedElements/SIF_ExtendedElement | PaymentReceipt/TransactionAmount | PaymentReceipt/TaxAmount | PaymentReceipt/SIF_ExtendedElements/SIF_ExtendedElement | PurchaseOrder/PurchasingItems/PurchasingItem/UnitCost | PurchaseOrder/PurchasingItems/PurchasingItem/TotalCost | PurchaseOrder/PurchasingItems/PurchasingItem/ExpenseAccounts/ExpenseAccount/Amount | PurchaseOrder/TaxAmount | PurchaseOrder/TotalAmount | PurchaseOrder/SIF_ExtendedElements/SIF_ExtendedElement | VendorInfo/ContactInfo/Address/StatisticalAreas/StatisticalArea | VendorInfo/ContactInfo/EmailList/Email | VendorInfo/SIF_ExtendedElements/SIF_ExtendedElement" mode="detect">
    <xsl:text>"</xsl:text><xsl:value-of select="name()"/>" : <xsl:apply-templates select="." mode="obj-content" />
    <xsl:if test="count(following-sibling::*) &gt; 0">, </xsl:if>
  </xsl:template>

  <!-- list -->
  <xsl:template match="Activity/SoftwareRequirementList/SoftwareRequirement | Activity/EssentialMaterials/EssentialMaterial | Activity/LearningObjectives/LearningObjective | Activity/LearningStandards/LearningStandardItemRefId | Activity/SubjectArea/OtherCodeList/OtherCode | Activity/Prerequisites/Prerequisite | Activity/Students/StudentPersonalRefId | Activity/SourceObjects/SourceObject | Activity/LearningResources/LearningResourceRefId | Activity/SIF_Metadata/TimeElements/TimeElement | Activity/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | Activity/SIF_Metadata/LifeCycle/Created/Creators/Creator | Activity/SIF_Metadata/LifeCycle/ModificationHistory/Modified | Activity/SIF_Metadata/LifeCycle/TimeElements/TimeElement | Activity/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | Activity/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | Activity/SIF_ExtendedElements/SIF_ExtendedElement | AggregateCharacteristicInfo/SIF_Metadata/TimeElements/TimeElement | AggregateCharacteristicInfo/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | AggregateCharacteristicInfo/SIF_Metadata/LifeCycle/Created/Creators/Creator | AggregateCharacteristicInfo/SIF_Metadata/LifeCycle/ModificationHistory/Modified | AggregateCharacteristicInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement | AggregateCharacteristicInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | AggregateCharacteristicInfo/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | AggregateCharacteristicInfo/SIF_ExtendedElements/SIF_ExtendedElement | AggregateStatisticFact/Characteristics/AggregateCharacteristicInfoRefId | AggregateStatisticFact/SIF_Metadata/TimeElements/TimeElement | AggregateStatisticFact/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | AggregateStatisticFact/SIF_Metadata/LifeCycle/Created/Creators/Creator | AggregateStatisticFact/SIF_Metadata/LifeCycle/ModificationHistory/Modified | AggregateStatisticFact/SIF_Metadata/LifeCycle/TimeElements/TimeElement | AggregateStatisticFact/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | AggregateStatisticFact/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | AggregateStatisticFact/SIF_ExtendedElements/SIF_ExtendedElement | AggregateStatisticInfo/ExclusionRules/ExclusionRule | AggregateStatisticInfo/SIF_Metadata/TimeElements/TimeElement | AggregateStatisticInfo/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | AggregateStatisticInfo/SIF_Metadata/LifeCycle/Created/Creators/Creator | AggregateStatisticInfo/SIF_Metadata/LifeCycle/ModificationHistory/Modified | AggregateStatisticInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement | AggregateStatisticInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | AggregateStatisticInfo/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | AggregateStatisticInfo/SIF_ExtendedElements/SIF_ExtendedElement | CalendarDate/CalendarDateType/OtherCodeList/OtherCode | CalendarDate/SIF_Metadata/TimeElements/TimeElement | CalendarDate/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | CalendarDate/SIF_Metadata/LifeCycle/Created/Creators/Creator | CalendarDate/SIF_Metadata/LifeCycle/ModificationHistory/Modified | CalendarDate/SIF_Metadata/LifeCycle/TimeElements/TimeElement | CalendarDate/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | CalendarDate/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | CalendarDate/SIF_ExtendedElements/SIF_ExtendedElement | CalendarSummary/YearLevels/YearLevel | CalendarSummary/SIF_Metadata/TimeElements/TimeElement | CalendarSummary/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | CalendarSummary/SIF_Metadata/LifeCycle/Created/Creators/Creator | CalendarSummary/SIF_Metadata/LifeCycle/ModificationHistory/Modified | CalendarSummary/SIF_Metadata/LifeCycle/TimeElements/TimeElement | CalendarSummary/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | CalendarSummary/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | CalendarSummary/SIF_ExtendedElements/SIF_ExtendedElement | EquipmentInfo/SIF_Metadata/TimeElements/TimeElement | EquipmentInfo/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | EquipmentInfo/SIF_Metadata/LifeCycle/Created/Creators/Creator | EquipmentInfo/SIF_Metadata/LifeCycle/ModificationHistory/Modified | EquipmentInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement | EquipmentInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | EquipmentInfo/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | EquipmentInfo/SIF_ExtendedElements/SIF_ExtendedElement | GradingAssignment/StudentPersonalRefIdList/StudentPersonalRefId | GradingAssignment/SubAssignmentList/GradingAssignmentRefId | GradingAssignment/RubricScoringGuide/ScoreList/Score | GradingAssignment/RubricScoringGuide/ScoreList/Score/ScoreDescriptionList/ScoreDescription | GradingAssignment/PrerequisiteList/Prerequisite | GradingAssignment/LearningStandardList/LearningStandard | GradingAssignment/LearningStandardList/LearningStandard/LearningStandardItemRefId | GradingAssignment/SIF_Metadata/TimeElements/TimeElement | GradingAssignment/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | GradingAssignment/SIF_Metadata/LifeCycle/Created/Creators/Creator | GradingAssignment/SIF_Metadata/LifeCycle/ModificationHistory/Modified | GradingAssignment/SIF_Metadata/LifeCycle/TimeElements/TimeElement | GradingAssignment/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | GradingAssignment/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | GradingAssignment/SIF_ExtendedElements/SIF_ExtendedElement | GradingAssignmentScore/SubscoreList/Subscore | GradingAssignmentScore/SIF_Metadata/TimeElements/TimeElement | GradingAssignmentScore/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | GradingAssignmentScore/SIF_Metadata/LifeCycle/Created/Creators/Creator | GradingAssignmentScore/SIF_Metadata/LifeCycle/ModificationHistory/Modified | GradingAssignmentScore/SIF_Metadata/LifeCycle/TimeElements/TimeElement | GradingAssignmentScore/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | GradingAssignmentScore/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | GradingAssignmentScore/SIF_ExtendedElements/SIF_ExtendedElement | Identity/IdentityAssertions/IdentityAssertion | Identity/PasswordList/Password | Identity/SIF_Metadata/TimeElements/TimeElement | Identity/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | Identity/SIF_Metadata/LifeCycle/Created/Creators/Creator | Identity/SIF_Metadata/LifeCycle/ModificationHistory/Modified | Identity/SIF_Metadata/LifeCycle/TimeElements/TimeElement | Identity/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | Identity/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | Identity/SIF_ExtendedElements/SIF_ExtendedElement | LEAInfo/EducationAgencyType/OtherCodeList/OtherCode | LEAInfo/LEAContactList/LEAContact | LEAInfo/LEAContactList/LEAContact/ContactInfo/Address/StatisticalAreas/StatisticalArea | LEAInfo/LEAContactList/LEAContact/ContactInfo/EmailList/Email | LEAInfo/LEAContactList/LEAContact/ContactInfo/PhoneNumberList/PhoneNumber | LEAInfo/PhoneNumberList/PhoneNumber | LEAInfo/AddressList/Address | LEAInfo/AddressList/Address/StatisticalAreas/StatisticalArea | LEAInfo/SIF_Metadata/TimeElements/TimeElement | LEAInfo/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | LEAInfo/SIF_Metadata/LifeCycle/Created/Creators/Creator | LEAInfo/SIF_Metadata/LifeCycle/ModificationHistory/Modified | LEAInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement | LEAInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | LEAInfo/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | LEAInfo/SIF_ExtendedElements/SIF_ExtendedElement | LearningResource/Contacts/Contact | LearningResource/Contacts/Contact/Address/StatisticalAreas/StatisticalArea | LearningResource/YearLevels/YearLevel | LearningResource/SubjectAreas/ACStrandSubjectArea | LearningResource/SubjectAreas/ACStrandSubjectArea/SubjectArea/OtherCodeList/OtherCode | LearningResource/MediaTypes/MediaType | LearningResource/Approvals/Approval | LearningResource/Evaluations/Evaluation | LearningResource/Components/Component | LearningResource/Components/Component/Strategies/Strategy | LearningResource/Components/Component/AssociatedObjects/AssociatedObject | LearningResource/LearningStandards/LearningStandardItemRefId | LearningResource/SIF_Metadata/TimeElements/TimeElement | LearningResource/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | LearningResource/SIF_Metadata/LifeCycle/Created/Creators/Creator | LearningResource/SIF_Metadata/LifeCycle/ModificationHistory/Modified | LearningResource/SIF_Metadata/LifeCycle/TimeElements/TimeElement | LearningResource/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | LearningResource/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | LearningResource/SIF_ExtendedElements/SIF_ExtendedElement | LearningStandardDocument/Organizations/Organization | LearningStandardDocument/Authors/Author | LearningStandardDocument/SubjectAreas/ACStrandSubjectArea | LearningStandardDocument/SubjectAreas/ACStrandSubjectArea/SubjectArea/OtherCodeList/OtherCode | LearningStandardDocument/YearLevels/YearLevel | LearningStandardDocument/RelatedLearningStandards/LearningStandardDocumentRefId | LearningStandardDocument/SIF_Metadata/TimeElements/TimeElement | LearningStandardDocument/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | LearningStandardDocument/SIF_Metadata/LifeCycle/Created/Creators/Creator | LearningStandardDocument/SIF_Metadata/LifeCycle/ModificationHistory/Modified | LearningStandardDocument/SIF_Metadata/LifeCycle/TimeElements/TimeElement | LearningStandardDocument/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | LearningStandardDocument/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | LearningStandardDocument/SIF_ExtendedElements/SIF_ExtendedElement | LearningStandardItem/Resources/LearningResourceRefId | LearningStandardItem/PredecessorItems/LearningStandardItemRefId | LearningStandardItem/StatementCodes/StatementCode | LearningStandardItem/Statements/Statement | LearningStandardItem/YearLevels/YearLevel | LearningStandardItem/ACStrandSubjectArea/SubjectArea/OtherCodeList/OtherCode | LearningStandardItem/StandardIdentifier/ACStrandSubjectArea/SubjectArea/OtherCodeList/OtherCode | LearningStandardItem/StandardIdentifier/YearLevels/YearLevel | LearningStandardItem/StandardIdentifier/AlternateIdentificationCodes/AlternateIdentificationCode | LearningStandardItem/RelatedLearningStandardItems/LearningStandardItemRefId | LearningStandardItem/SIF_Metadata/TimeElements/TimeElement | LearningStandardItem/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | LearningStandardItem/SIF_Metadata/LifeCycle/Created/Creators/Creator | LearningStandardItem/SIF_Metadata/LifeCycle/ModificationHistory/Modified | LearningStandardItem/SIF_Metadata/LifeCycle/TimeElements/TimeElement | LearningStandardItem/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | LearningStandardItem/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | LearningStandardItem/SIF_ExtendedElements/SIF_ExtendedElement | MarkValueInfo/YearLevels/YearLevel | MarkValueInfo/ValidLetterMarkList/ValidLetterMark | MarkValueInfo/SIF_Metadata/TimeElements/TimeElement | MarkValueInfo/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | MarkValueInfo/SIF_Metadata/LifeCycle/Created/Creators/Creator | MarkValueInfo/SIF_Metadata/LifeCycle/ModificationHistory/Modified | MarkValueInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement | MarkValueInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | MarkValueInfo/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | MarkValueInfo/SIF_ExtendedElements/SIF_ExtendedElement | PersonPicture/SIF_Metadata/TimeElements/TimeElement | PersonPicture/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | PersonPicture/SIF_Metadata/LifeCycle/Created/Creators/Creator | PersonPicture/SIF_Metadata/LifeCycle/ModificationHistory/Modified | PersonPicture/SIF_Metadata/LifeCycle/TimeElements/TimeElement | PersonPicture/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | PersonPicture/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | PersonPicture/SIF_ExtendedElements/SIF_ExtendedElement | PersonPrivacyObligation/DataDomainObligationList/DataDomainObligation | PersonPrivacyObligation/DataDomainObligationList/DataDomainObligation/ShareWithList/ShareWith | PersonPrivacyObligation/SIF_Metadata/TimeElements/TimeElement | PersonPrivacyObligation/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | PersonPrivacyObligation/SIF_Metadata/LifeCycle/Created/Creators/Creator | PersonPrivacyObligation/SIF_Metadata/LifeCycle/ModificationHistory/Modified | PersonPrivacyObligation/SIF_Metadata/LifeCycle/TimeElements/TimeElement | PersonPrivacyObligation/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | PersonPrivacyObligation/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | PersonPrivacyObligation/SIF_ExtendedElements/SIF_ExtendedElement | PersonalisedPlan/DocumentList/Document | PersonalisedPlan/SIF_Metadata/TimeElements/TimeElement | PersonalisedPlan/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | PersonalisedPlan/SIF_Metadata/LifeCycle/Created/Creators/Creator | PersonalisedPlan/SIF_Metadata/LifeCycle/ModificationHistory/Modified | PersonalisedPlan/SIF_Metadata/LifeCycle/TimeElements/TimeElement | PersonalisedPlan/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | PersonalisedPlan/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | PersonalisedPlan/SIF_ExtendedElements/SIF_ExtendedElement | ReportAuthorityInfo/ContactInfo/Address/StatisticalAreas/StatisticalArea | ReportAuthorityInfo/ContactInfo/EmailList/Email | ReportAuthorityInfo/ContactInfo/PhoneNumberList/PhoneNumber | ReportAuthorityInfo/Address/StatisticalAreas/StatisticalArea | ReportAuthorityInfo/SIF_Metadata/TimeElements/TimeElement | ReportAuthorityInfo/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | ReportAuthorityInfo/SIF_Metadata/LifeCycle/Created/Creators/Creator | ReportAuthorityInfo/SIF_Metadata/LifeCycle/ModificationHistory/Modified | ReportAuthorityInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement | ReportAuthorityInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | ReportAuthorityInfo/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | ReportAuthorityInfo/SIF_ExtendedElements/SIF_ExtendedElement | ResourceBooking/SIF_Metadata/TimeElements/TimeElement | ResourceBooking/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | ResourceBooking/SIF_Metadata/LifeCycle/Created/Creators/Creator | ResourceBooking/SIF_Metadata/LifeCycle/ModificationHistory/Modified | ResourceBooking/SIF_Metadata/LifeCycle/TimeElements/TimeElement | ResourceBooking/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | ResourceBooking/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | ResourceBooking/SIF_ExtendedElements/SIF_ExtendedElement | ResourceUsage/ResourceReportColumnList/ResourceReportColumn | ResourceUsage/ResourceReportLineList/ResourceReportLine | ResourceUsage/SIF_Metadata/TimeElements/TimeElement | ResourceUsage/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | ResourceUsage/SIF_Metadata/LifeCycle/Created/Creators/Creator | ResourceUsage/SIF_Metadata/LifeCycle/ModificationHistory/Modified | ResourceUsage/SIF_Metadata/LifeCycle/TimeElements/TimeElement | ResourceUsage/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | ResourceUsage/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | ResourceUsage/SIF_ExtendedElements/SIF_ExtendedElement | RoomInfo/StaffList/StaffPersonalRefId | RoomInfo/SIF_Metadata/TimeElements/TimeElement | RoomInfo/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | RoomInfo/SIF_Metadata/LifeCycle/Created/Creators/Creator | RoomInfo/SIF_Metadata/LifeCycle/ModificationHistory/Modified | RoomInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement | RoomInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | RoomInfo/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | RoomInfo/SIF_ExtendedElements/SIF_ExtendedElement | ScheduledActivity/TeacherList/TeacherCover | ScheduledActivity/RoomList/RoomInfoRefId | ScheduledActivity/AddressList/Address | ScheduledActivity/AddressList/Address/StatisticalAreas/StatisticalArea | ScheduledActivity/StudentList/StudentPersonalRefId | ScheduledActivity/TeachingGroupList/TeachingGroupRefId | ScheduledActivity/YearLevels/YearLevel | ScheduledActivity/SIF_Metadata/TimeElements/TimeElement | ScheduledActivity/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | ScheduledActivity/SIF_Metadata/LifeCycle/Created/Creators/Creator | ScheduledActivity/SIF_Metadata/LifeCycle/ModificationHistory/Modified | ScheduledActivity/SIF_Metadata/LifeCycle/TimeElements/TimeElement | ScheduledActivity/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | ScheduledActivity/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | ScheduledActivity/SIF_ExtendedElements/SIF_ExtendedElement | SchoolCourseInfo/SubjectAreaList/SubjectArea | SchoolCourseInfo/SubjectAreaList/SubjectArea/OtherCodeList/OtherCode | SchoolCourseInfo/SIF_Metadata/TimeElements/TimeElement | SchoolCourseInfo/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | SchoolCourseInfo/SIF_Metadata/LifeCycle/Created/Creators/Creator | SchoolCourseInfo/SIF_Metadata/LifeCycle/ModificationHistory/Modified | SchoolCourseInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement | SchoolCourseInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | SchoolCourseInfo/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | SchoolCourseInfo/SIF_ExtendedElements/SIF_ExtendedElement | SchoolInfo/OtherIdList/OtherId | SchoolInfo/SchoolFocusList/SchoolFocus | SchoolInfo/SchoolEmailList/Email | SchoolInfo/PrincipalInfo/PhoneNumberList/PhoneNumber | SchoolInfo/PrincipalInfo/EmailList/Email | SchoolInfo/SchoolContactList/SchoolContact | SchoolInfo/SchoolContactList/SchoolContact/ContactInfo/Address/StatisticalAreas/StatisticalArea | SchoolInfo/SchoolContactList/SchoolContact/ContactInfo/EmailList/Email | SchoolInfo/SchoolContactList/SchoolContact/ContactInfo/PhoneNumberList/PhoneNumber | SchoolInfo/AddressList/Address | SchoolInfo/AddressList/Address/StatisticalAreas/StatisticalArea | SchoolInfo/PhoneNumberList/PhoneNumber | SchoolInfo/YearLevels/YearLevel | SchoolInfo/YearLevelEnrollmentList/YearLevelEnrollment | SchoolInfo/SchoolGroupList/SchoolGroup | SchoolInfo/SIF_Metadata/TimeElements/TimeElement | SchoolInfo/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | SchoolInfo/SIF_Metadata/LifeCycle/Created/Creators/Creator | SchoolInfo/SIF_Metadata/LifeCycle/ModificationHistory/Modified | SchoolInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement | SchoolInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | SchoolInfo/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | SchoolInfo/SIF_ExtendedElements/SIF_ExtendedElement | SchoolPrograms/SchoolProgramList/Program | SchoolPrograms/SchoolProgramList/Program/OtherCodeList/OtherCode | SchoolPrograms/SIF_Metadata/TimeElements/TimeElement | SchoolPrograms/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | SchoolPrograms/SIF_Metadata/LifeCycle/Created/Creators/Creator | SchoolPrograms/SIF_Metadata/LifeCycle/ModificationHistory/Modified | SchoolPrograms/SIF_Metadata/LifeCycle/TimeElements/TimeElement | SchoolPrograms/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | SchoolPrograms/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | SchoolPrograms/SIF_ExtendedElements/SIF_ExtendedElement | SectionInfo/MediumOfInstruction/OtherCodeList/OtherCode | SectionInfo/LanguageOfInstruction/OtherCodeList/OtherCode | SectionInfo/LocationOfInstruction/OtherCodeList/OtherCode | SectionInfo/SchoolCourseInfoOverride/SubjectArea/OtherCodeList/OtherCode | SectionInfo/SIF_Metadata/TimeElements/TimeElement | SectionInfo/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | SectionInfo/SIF_Metadata/LifeCycle/Created/Creators/Creator | SectionInfo/SIF_Metadata/LifeCycle/ModificationHistory/Modified | SectionInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement | SectionInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | SectionInfo/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | SectionInfo/SIF_ExtendedElements/SIF_ExtendedElement | SessionInfo/SIF_Metadata/TimeElements/TimeElement | SessionInfo/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | SessionInfo/SIF_Metadata/LifeCycle/Created/Creators/Creator | SessionInfo/SIF_Metadata/LifeCycle/ModificationHistory/Modified | SessionInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement | SessionInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | SessionInfo/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | SessionInfo/SIF_ExtendedElements/SIF_ExtendedElement | StaffAssignment/StaffSubjectList/StaffSubject | StaffAssignment/StaffActivity/OtherCodeList/OtherCode | StaffAssignment/YearLevels/YearLevel | StaffAssignment/CalendarSummaryList/CalendarSummaryRefId | StaffAssignment/SIF_Metadata/TimeElements/TimeElement | StaffAssignment/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | StaffAssignment/SIF_Metadata/LifeCycle/Created/Creators/Creator | StaffAssignment/SIF_Metadata/LifeCycle/ModificationHistory/Modified | StaffAssignment/SIF_Metadata/LifeCycle/TimeElements/TimeElement | StaffAssignment/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | StaffAssignment/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | StaffAssignment/SIF_ExtendedElements/SIF_ExtendedElement | StaffPersonal/ElectronicIdList/ElectronicId | StaffPersonal/OtherIdList/OtherId | StaffPersonal/PersonInfo/OtherNames/Name | StaffPersonal/PersonInfo/Demographics/CountriesOfCitizenship/CountryOfCitizenship | StaffPersonal/PersonInfo/Demographics/CountriesOfResidency/CountryOfResidency | StaffPersonal/PersonInfo/Demographics/EnglishProficiency/OtherCodeList/OtherCode | StaffPersonal/PersonInfo/Demographics/LanguageList/Language | StaffPersonal/PersonInfo/Demographics/LanguageList/Language/OtherCodeList/OtherCode | StaffPersonal/PersonInfo/Demographics/DwellingArrangement/OtherCodeList/OtherCode | StaffPersonal/PersonInfo/Demographics/Religion/OtherCodeList/OtherCode | StaffPersonal/PersonInfo/Demographics/ReligiousEventList/ReligiousEvent | StaffPersonal/PersonInfo/Demographics/VisaSubClassList/VisaSubClass | StaffPersonal/PersonInfo/AddressList/Address | StaffPersonal/PersonInfo/AddressList/Address/StatisticalAreas/StatisticalArea | StaffPersonal/PersonInfo/PhoneNumberList/PhoneNumber | StaffPersonal/PersonInfo/EmailList/Email | StaffPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo | StaffPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/AddressList/Address | StaffPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/AddressList/Address/StatisticalAreas/StatisticalArea | StaffPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/EmailList/Email | StaffPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/PhoneNumberList/PhoneNumber | StaffPersonal/MostRecent/NAPLANClassList/ClassCode | StaffPersonal/SIF_Metadata/TimeElements/TimeElement | StaffPersonal/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | StaffPersonal/SIF_Metadata/LifeCycle/Created/Creators/Creator | StaffPersonal/SIF_Metadata/LifeCycle/ModificationHistory/Modified | StaffPersonal/SIF_Metadata/LifeCycle/TimeElements/TimeElement | StaffPersonal/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | StaffPersonal/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | StaffPersonal/SIF_ExtendedElements/SIF_ExtendedElement | StudentActivityInfo/StudentActivityType/OtherCodeList/OtherCode | StudentActivityInfo/YearLevels/YearLevel | StudentActivityInfo/SIF_Metadata/TimeElements/TimeElement | StudentActivityInfo/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | StudentActivityInfo/SIF_Metadata/LifeCycle/Created/Creators/Creator | StudentActivityInfo/SIF_Metadata/LifeCycle/ModificationHistory/Modified | StudentActivityInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement | StudentActivityInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | StudentActivityInfo/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | StudentActivityInfo/SIF_ExtendedElements/SIF_ExtendedElement | StudentActivityParticipation/RecognitionList/Recognition | StudentActivityParticipation/SIF_Metadata/TimeElements/TimeElement | StudentActivityParticipation/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | StudentActivityParticipation/SIF_Metadata/LifeCycle/Created/Creators/Creator | StudentActivityParticipation/SIF_Metadata/LifeCycle/ModificationHistory/Modified | StudentActivityParticipation/SIF_Metadata/LifeCycle/TimeElements/TimeElement | StudentActivityParticipation/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | StudentActivityParticipation/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | StudentActivityParticipation/SIF_ExtendedElements/SIF_ExtendedElement | StudentAttendanceSummary/SIF_Metadata/TimeElements/TimeElement | StudentAttendanceSummary/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | StudentAttendanceSummary/SIF_Metadata/LifeCycle/Created/Creators/Creator | StudentAttendanceSummary/SIF_Metadata/LifeCycle/ModificationHistory/Modified | StudentAttendanceSummary/SIF_Metadata/LifeCycle/TimeElements/TimeElement | StudentAttendanceSummary/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | StudentAttendanceSummary/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | StudentAttendanceSummary/SIF_ExtendedElements/SIF_ExtendedElement | StudentAttendanceTimeList/AttendanceTimes/AttendanceTime | StudentAttendanceTimeList/AttendanceTimes/AttendanceTime/AttendanceCode/OtherCodeList/OtherCode | StudentAttendanceTimeList/PeriodAttendances/PeriodAttendance | StudentAttendanceTimeList/PeriodAttendances/PeriodAttendance/AttendanceCode/OtherCodeList/OtherCode | StudentAttendanceTimeList/PeriodAttendances/PeriodAttendance/TeacherList/TeacherCover | StudentAttendanceTimeList/PeriodAttendances/PeriodAttendance/RoomList/RoomInfoRefId | StudentAttendanceTimeList/SIF_Metadata/TimeElements/TimeElement | StudentAttendanceTimeList/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | StudentAttendanceTimeList/SIF_Metadata/LifeCycle/Created/Creators/Creator | StudentAttendanceTimeList/SIF_Metadata/LifeCycle/ModificationHistory/Modified | StudentAttendanceTimeList/SIF_Metadata/LifeCycle/TimeElements/TimeElement | StudentAttendanceTimeList/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | StudentAttendanceTimeList/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | StudentAttendanceTimeList/SIF_ExtendedElements/SIF_ExtendedElement | StudentContactPersonal/OtherIdList/OtherId | StudentContactPersonal/PersonInfo/OtherNames/Name | StudentContactPersonal/PersonInfo/Demographics/CountriesOfCitizenship/CountryOfCitizenship | StudentContactPersonal/PersonInfo/Demographics/CountriesOfResidency/CountryOfResidency | StudentContactPersonal/PersonInfo/Demographics/EnglishProficiency/OtherCodeList/OtherCode | StudentContactPersonal/PersonInfo/Demographics/LanguageList/Language | StudentContactPersonal/PersonInfo/Demographics/LanguageList/Language/OtherCodeList/OtherCode | StudentContactPersonal/PersonInfo/Demographics/DwellingArrangement/OtherCodeList/OtherCode | StudentContactPersonal/PersonInfo/Demographics/Religion/OtherCodeList/OtherCode | StudentContactPersonal/PersonInfo/Demographics/ReligiousEventList/ReligiousEvent | StudentContactPersonal/PersonInfo/Demographics/VisaSubClassList/VisaSubClass | StudentContactPersonal/PersonInfo/AddressList/Address | StudentContactPersonal/PersonInfo/AddressList/Address/StatisticalAreas/StatisticalArea | StudentContactPersonal/PersonInfo/PhoneNumberList/PhoneNumber | StudentContactPersonal/PersonInfo/EmailList/Email | StudentContactPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo | StudentContactPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/AddressList/Address | StudentContactPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/AddressList/Address/StatisticalAreas/StatisticalArea | StudentContactPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/EmailList/Email | StudentContactPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/PhoneNumberList/PhoneNumber | StudentContactPersonal/SIF_Metadata/TimeElements/TimeElement | StudentContactPersonal/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | StudentContactPersonal/SIF_Metadata/LifeCycle/Created/Creators/Creator | StudentContactPersonal/SIF_Metadata/LifeCycle/ModificationHistory/Modified | StudentContactPersonal/SIF_Metadata/LifeCycle/TimeElements/TimeElement | StudentContactPersonal/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | StudentContactPersonal/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | StudentContactPersonal/SIF_ExtendedElements/SIF_ExtendedElement | StudentContactRelationship/Relationship/OtherCodeList/OtherCode | StudentContactRelationship/HouseholdList/Household | StudentContactRelationship/SIF_Metadata/TimeElements/TimeElement | StudentContactRelationship/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | StudentContactRelationship/SIF_Metadata/LifeCycle/Created/Creators/Creator | StudentContactRelationship/SIF_Metadata/LifeCycle/ModificationHistory/Modified | StudentContactRelationship/SIF_Metadata/LifeCycle/TimeElements/TimeElement | StudentContactRelationship/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | StudentContactRelationship/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | StudentContactRelationship/SIF_ExtendedElements/SIF_ExtendedElement | StudentDailyAttendance/AttendanceCode/OtherCodeList/OtherCode | StudentDailyAttendance/SIF_Metadata/TimeElements/TimeElement | StudentDailyAttendance/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | StudentDailyAttendance/SIF_Metadata/LifeCycle/Created/Creators/Creator | StudentDailyAttendance/SIF_Metadata/LifeCycle/ModificationHistory/Modified | StudentDailyAttendance/SIF_Metadata/LifeCycle/TimeElements/TimeElement | StudentDailyAttendance/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | StudentDailyAttendance/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | StudentDailyAttendance/SIF_ExtendedElements/SIF_ExtendedElement | StudentGrade/Markers/Marker | StudentGrade/LearningArea/SubjectArea/OtherCodeList/OtherCode | StudentGrade/LearningStandardList/LearningStandard | StudentGrade/LearningStandardList/LearningStandard/LearningStandardItemRefId | StudentGrade/GradingScoreList/GradingAssignmentScore | StudentGrade/SIF_Metadata/TimeElements/TimeElement | StudentGrade/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | StudentGrade/SIF_Metadata/LifeCycle/Created/Creators/Creator | StudentGrade/SIF_Metadata/LifeCycle/ModificationHistory/Modified | StudentGrade/SIF_Metadata/LifeCycle/TimeElements/TimeElement | StudentGrade/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | StudentGrade/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | StudentGrade/SIF_ExtendedElements/SIF_ExtendedElement | StudentParticipation/ProgramFundingSources/ProgramFundingSource | StudentParticipation/ProgramFundingSources/ProgramFundingSource/OtherCodeList/OtherCode | StudentParticipation/ReferralSource/OtherCodeList/OtherCode | StudentParticipation/ProgramStatus/OtherCodeList/OtherCode | StudentParticipation/ProgramAvailability/OtherCodeList/OtherCode | StudentParticipation/SIF_Metadata/TimeElements/TimeElement | StudentParticipation/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | StudentParticipation/SIF_Metadata/LifeCycle/Created/Creators/Creator | StudentParticipation/SIF_Metadata/LifeCycle/ModificationHistory/Modified | StudentParticipation/SIF_Metadata/LifeCycle/TimeElements/TimeElement | StudentParticipation/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | StudentParticipation/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | StudentParticipation/SIF_ExtendedElements/SIF_ExtendedElement | StudentPeriodAttendance/AttendanceCode/OtherCodeList/OtherCode | StudentPeriodAttendance/SIF_Metadata/TimeElements/TimeElement | StudentPeriodAttendance/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | StudentPeriodAttendance/SIF_Metadata/LifeCycle/Created/Creators/Creator | StudentPeriodAttendance/SIF_Metadata/LifeCycle/ModificationHistory/Modified | StudentPeriodAttendance/SIF_Metadata/LifeCycle/TimeElements/TimeElement | StudentPeriodAttendance/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | StudentPeriodAttendance/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | StudentPeriodAttendance/SIF_ExtendedElements/SIF_ExtendedElement | StudentPersonal/AlertMessages/AlertMessage | StudentPersonal/MedicalAlertMessages/MedicalAlertMessage | StudentPersonal/ElectronicIdList/ElectronicId | StudentPersonal/OtherIdList/OtherId | StudentPersonal/PersonInfo/OtherNames/Name | StudentPersonal/PersonInfo/Demographics/CountriesOfCitizenship/CountryOfCitizenship | StudentPersonal/PersonInfo/Demographics/CountriesOfResidency/CountryOfResidency | StudentPersonal/PersonInfo/Demographics/EnglishProficiency/OtherCodeList/OtherCode | StudentPersonal/PersonInfo/Demographics/LanguageList/Language | StudentPersonal/PersonInfo/Demographics/LanguageList/Language/OtherCodeList/OtherCode | StudentPersonal/PersonInfo/Demographics/DwellingArrangement/OtherCodeList/OtherCode | StudentPersonal/PersonInfo/Demographics/Religion/OtherCodeList/OtherCode | StudentPersonal/PersonInfo/Demographics/ReligiousEventList/ReligiousEvent | StudentPersonal/PersonInfo/Demographics/VisaSubClassList/VisaSubClass | StudentPersonal/PersonInfo/AddressList/Address | StudentPersonal/PersonInfo/AddressList/Address/StatisticalAreas/StatisticalArea | StudentPersonal/PersonInfo/PhoneNumberList/PhoneNumber | StudentPersonal/PersonInfo/EmailList/Email | StudentPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo | StudentPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/AddressList/Address | StudentPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/AddressList/Address/StatisticalAreas/StatisticalArea | StudentPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/EmailList/Email | StudentPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/PhoneNumberList/PhoneNumber | StudentPersonal/SIF_Metadata/TimeElements/TimeElement | StudentPersonal/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | StudentPersonal/SIF_Metadata/LifeCycle/Created/Creators/Creator | StudentPersonal/SIF_Metadata/LifeCycle/ModificationHistory/Modified | StudentPersonal/SIF_Metadata/LifeCycle/TimeElements/TimeElement | StudentPersonal/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | StudentPersonal/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | StudentPersonal/SIF_ExtendedElements/SIF_ExtendedElement | StudentSchoolEnrollment/EntryType/OtherCodeList/OtherCode | StudentSchoolEnrollment/ExitStatus/OtherCodeList/OtherCode | StudentSchoolEnrollment/ExitType/OtherCodeList/OtherCode | StudentSchoolEnrollment/CatchmentStatus/OtherCodeList/OtherCode | StudentSchoolEnrollment/StudentSubjectChoiceList/StudentSubjectChoice | StudentSchoolEnrollment/StudentSubjectChoiceList/StudentSubjectChoice/StudyDescription/OtherCodeList/OtherCode | StudentSchoolEnrollment/SIF_Metadata/TimeElements/TimeElement | StudentSchoolEnrollment/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | StudentSchoolEnrollment/SIF_Metadata/LifeCycle/Created/Creators/Creator | StudentSchoolEnrollment/SIF_Metadata/LifeCycle/ModificationHistory/Modified | StudentSchoolEnrollment/SIF_Metadata/LifeCycle/TimeElements/TimeElement | StudentSchoolEnrollment/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | StudentSchoolEnrollment/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | StudentSchoolEnrollment/SIF_ExtendedElements/SIF_ExtendedElement | StudentSectionEnrollment/SIF_Metadata/TimeElements/TimeElement | StudentSectionEnrollment/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | StudentSectionEnrollment/SIF_Metadata/LifeCycle/Created/Creators/Creator | StudentSectionEnrollment/SIF_Metadata/LifeCycle/ModificationHistory/Modified | StudentSectionEnrollment/SIF_Metadata/LifeCycle/TimeElements/TimeElement | StudentSectionEnrollment/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | StudentSectionEnrollment/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | StudentSectionEnrollment/SIF_ExtendedElements/SIF_ExtendedElement | SystemRole/SystemContextList/SystemContext | SystemRole/SystemContextList/SystemContext/RoleList/Role | SystemRole/SystemContextList/SystemContext/RoleList/Role/RoleScopeList/RoleScope | SystemRole/SIF_Metadata/TimeElements/TimeElement | SystemRole/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | SystemRole/SIF_Metadata/LifeCycle/Created/Creators/Creator | SystemRole/SIF_Metadata/LifeCycle/ModificationHistory/Modified | SystemRole/SIF_Metadata/LifeCycle/TimeElements/TimeElement | SystemRole/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | SystemRole/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | SystemRole/SIF_ExtendedElements/SIF_ExtendedElement | TeachingGroup/StudentList/TeachingGroupStudent | TeachingGroup/TeacherList/TeachingGroupTeacher | TeachingGroup/TeachingGroupPeriodList/TeachingGroupPeriod | TeachingGroup/SIF_Metadata/TimeElements/TimeElement | TeachingGroup/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | TeachingGroup/SIF_Metadata/LifeCycle/Created/Creators/Creator | TeachingGroup/SIF_Metadata/LifeCycle/ModificationHistory/Modified | TeachingGroup/SIF_Metadata/LifeCycle/TimeElements/TimeElement | TeachingGroup/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | TeachingGroup/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | TeachingGroup/SIF_ExtendedElements/SIF_ExtendedElement | TermInfo/SIF_Metadata/TimeElements/TimeElement | TermInfo/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | TermInfo/SIF_Metadata/LifeCycle/Created/Creators/Creator | TermInfo/SIF_Metadata/LifeCycle/ModificationHistory/Modified | TermInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement | TermInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | TermInfo/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | TermInfo/SIF_ExtendedElements/SIF_ExtendedElement | TimeTable/TimeTableDayList/TimeTableDay | TimeTable/TimeTableDayList/TimeTableDay/TimeTablePeriodList/TimeTablePeriod | TimeTable/SIF_Metadata/TimeElements/TimeElement | TimeTable/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | TimeTable/SIF_Metadata/LifeCycle/Created/Creators/Creator | TimeTable/SIF_Metadata/LifeCycle/ModificationHistory/Modified | TimeTable/SIF_Metadata/LifeCycle/TimeElements/TimeElement | TimeTable/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | TimeTable/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | TimeTable/SIF_ExtendedElements/SIF_ExtendedElement | TimeTableCell/TeacherList/TeacherCover | TimeTableCell/RoomList/RoomInfoRefId | TimeTableCell/SIF_Metadata/TimeElements/TimeElement | TimeTableCell/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | TimeTableCell/SIF_Metadata/LifeCycle/Created/Creators/Creator | TimeTableCell/SIF_Metadata/LifeCycle/ModificationHistory/Modified | TimeTableCell/SIF_Metadata/LifeCycle/TimeElements/TimeElement | TimeTableCell/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | TimeTableCell/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | TimeTableCell/SIF_ExtendedElements/SIF_ExtendedElement | TimeTableSubject/OtherCodeList/OtherCode | TimeTableSubject/SIF_Metadata/TimeElements/TimeElement | TimeTableSubject/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | TimeTableSubject/SIF_Metadata/LifeCycle/Created/Creators/Creator | TimeTableSubject/SIF_Metadata/LifeCycle/ModificationHistory/Modified | TimeTableSubject/SIF_Metadata/LifeCycle/TimeElements/TimeElement | TimeTableSubject/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | TimeTableSubject/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | TimeTableSubject/SIF_ExtendedElements/SIF_ExtendedElement | WellbeingAlert/SIF_Metadata/TimeElements/TimeElement | WellbeingAlert/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | WellbeingAlert/SIF_Metadata/LifeCycle/Created/Creators/Creator | WellbeingAlert/SIF_Metadata/LifeCycle/ModificationHistory/Modified | WellbeingAlert/SIF_Metadata/LifeCycle/TimeElements/TimeElement | WellbeingAlert/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | WellbeingAlert/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | WellbeingAlert/SIF_ExtendedElements/SIF_ExtendedElement | WellbeingAppeal/DocumentList/Document | WellbeingAppeal/SIF_Metadata/TimeElements/TimeElement | WellbeingAppeal/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | WellbeingAppeal/SIF_Metadata/LifeCycle/Created/Creators/Creator | WellbeingAppeal/SIF_Metadata/LifeCycle/ModificationHistory/Modified | WellbeingAppeal/SIF_Metadata/LifeCycle/TimeElements/TimeElement | WellbeingAppeal/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | WellbeingAppeal/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | WellbeingAppeal/SIF_ExtendedElements/SIF_ExtendedElement | WellbeingCharacteristic/MedicationList/Medication | WellbeingCharacteristic/DocumentList/Document | WellbeingCharacteristic/SIF_Metadata/TimeElements/TimeElement | WellbeingCharacteristic/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | WellbeingCharacteristic/SIF_Metadata/LifeCycle/Created/Creators/Creator | WellbeingCharacteristic/SIF_Metadata/LifeCycle/ModificationHistory/Modified | WellbeingCharacteristic/SIF_Metadata/LifeCycle/TimeElements/TimeElement | WellbeingCharacteristic/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | WellbeingCharacteristic/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | WellbeingCharacteristic/SIF_ExtendedElements/SIF_ExtendedElement | WellbeingEvent/WellbeingEventCategoryList/WellbeingEventCategory | WellbeingEvent/WellbeingEventCategoryList/WellbeingEventCategory/WellbeingEventSubCategoryList/WellbeingEventSubCategory | WellbeingEvent/PersonInvolvementList/PersonInvolvement | WellbeingEvent/FollowUpActionList/FollowUpAction | WellbeingEvent/DocumentList/Document | WellbeingEvent/SIF_Metadata/TimeElements/TimeElement | WellbeingEvent/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | WellbeingEvent/SIF_Metadata/LifeCycle/Created/Creators/Creator | WellbeingEvent/SIF_Metadata/LifeCycle/ModificationHistory/Modified | WellbeingEvent/SIF_Metadata/LifeCycle/TimeElements/TimeElement | WellbeingEvent/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | WellbeingEvent/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | WellbeingEvent/SIF_ExtendedElements/SIF_ExtendedElement | WellbeingResponse/PersonInvolvementList/PersonInvolvement | WellbeingResponse/Suspension/WithdrawalTimeList/Withdrawal | WellbeingResponse/PlanRequired/PlanRequiredList/Plan | WellbeingResponse/DocumentList/Document | WellbeingResponse/SIF_Metadata/TimeElements/TimeElement | WellbeingResponse/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | WellbeingResponse/SIF_Metadata/LifeCycle/Created/Creators/Creator | WellbeingResponse/SIF_Metadata/LifeCycle/ModificationHistory/Modified | WellbeingResponse/SIF_Metadata/LifeCycle/TimeElements/TimeElement | WellbeingResponse/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | WellbeingResponse/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | WellbeingResponse/SIF_ExtendedElements/SIF_ExtendedElement | AGStatusReport/AGReportingObjectResponseList/AGReportingObjectResponse | AGStatusReport/AGReportingObjectResponseList/AGReportingObjectResponse/AGRuleList/AGRule | AGStatusReport/SIF_Metadata/TimeElements/TimeElement | AGStatusReport/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | AGStatusReport/SIF_Metadata/LifeCycle/Created/Creators/Creator | AGStatusReport/SIF_Metadata/LifeCycle/ModificationHistory/Modified | AGStatusReport/SIF_Metadata/LifeCycle/TimeElements/TimeElement | AGStatusReport/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | AGStatusReport/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | AGStatusReport/SIF_ExtendedElements/SIF_ExtendedElement | ChargedLocationInfo/AddressList/Address | ChargedLocationInfo/AddressList/Address/StatisticalAreas/StatisticalArea | ChargedLocationInfo/PhoneNumberList/PhoneNumber | ChargedLocationInfo/SIF_Metadata/TimeElements/TimeElement | ChargedLocationInfo/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | ChargedLocationInfo/SIF_Metadata/LifeCycle/Created/Creators/Creator | ChargedLocationInfo/SIF_Metadata/LifeCycle/ModificationHistory/Modified | ChargedLocationInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement | ChargedLocationInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | ChargedLocationInfo/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | ChargedLocationInfo/SIF_ExtendedElements/SIF_ExtendedElement | Debtor/AddressList/Address | Debtor/AddressList/Address/StatisticalAreas/StatisticalArea | Debtor/SIF_Metadata/TimeElements/TimeElement | Debtor/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | Debtor/SIF_Metadata/LifeCycle/Created/Creators/Creator | Debtor/SIF_Metadata/LifeCycle/ModificationHistory/Modified | Debtor/SIF_Metadata/LifeCycle/TimeElements/TimeElement | Debtor/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | Debtor/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | Debtor/SIF_ExtendedElements/SIF_ExtendedElement | FQReporting/EntityContact/Address/StatisticalAreas/StatisticalArea | FQReporting/FQContextualQuestionList/FQContextualQuestion | FQReporting/FQItemList/FQItem | FQReporting/AGRuleList/AGRule | FQReporting/SIF_Metadata/TimeElements/TimeElement | FQReporting/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | FQReporting/SIF_Metadata/LifeCycle/Created/Creators/Creator | FQReporting/SIF_Metadata/LifeCycle/ModificationHistory/Modified | FQReporting/SIF_Metadata/LifeCycle/TimeElements/TimeElement | FQReporting/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | FQReporting/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | FQReporting/SIF_ExtendedElements/SIF_ExtendedElement | FinancialAccount/SIF_Metadata/TimeElements/TimeElement | FinancialAccount/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | FinancialAccount/SIF_Metadata/LifeCycle/Created/Creators/Creator | FinancialAccount/SIF_Metadata/LifeCycle/ModificationHistory/Modified | FinancialAccount/SIF_Metadata/LifeCycle/TimeElements/TimeElement | FinancialAccount/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | FinancialAccount/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | FinancialAccount/SIF_ExtendedElements/SIF_ExtendedElement | Invoice/FinancialAccountRefIdList/FinancialAccountRefId | Invoice/PurchasingItems/PurchasingItem | Invoice/PurchasingItems/PurchasingItem/ExpenseAccounts/ExpenseAccount | Invoice/SIF_Metadata/TimeElements/TimeElement | Invoice/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | Invoice/SIF_Metadata/LifeCycle/Created/Creators/Creator | Invoice/SIF_Metadata/LifeCycle/ModificationHistory/Modified | Invoice/SIF_Metadata/LifeCycle/TimeElements/TimeElement | Invoice/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | Invoice/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | Invoice/SIF_ExtendedElements/SIF_ExtendedElement | Journal/SIF_Metadata/TimeElements/TimeElement | Journal/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | Journal/SIF_Metadata/LifeCycle/Created/Creators/Creator | Journal/SIF_Metadata/LifeCycle/ModificationHistory/Modified | Journal/SIF_Metadata/LifeCycle/TimeElements/TimeElement | Journal/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | Journal/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | Journal/SIF_ExtendedElements/SIF_ExtendedElement | NAPCodeFrame/TestletList/Testlet | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem/TestItemContent/ItemSubstitutedForList/SubstituteItem | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem/TestItemContent/ItemSubstitutedForList/SubstituteItem/PNPCodeList/PNPCode | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem/TestItemContent/ContentDescriptionList/ContentDescription | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem/TestItemContent/StimulusList/Stimulus | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem/TestItemContent/NAPWritingRubricList/NAPWritingRubric | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem/TestItemContent/NAPWritingRubricList/NAPWritingRubric/ScoreList/Score | NAPCodeFrame/TestletList/Testlet/TestItemList/TestItem/TestItemContent/NAPWritingRubricList/NAPWritingRubric/ScoreList/Score/ScoreDescriptionList/ScoreDescription | NAPCodeFrame/SIF_Metadata/TimeElements/TimeElement | NAPCodeFrame/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | NAPCodeFrame/SIF_Metadata/LifeCycle/Created/Creators/Creator | NAPCodeFrame/SIF_Metadata/LifeCycle/ModificationHistory/Modified | NAPCodeFrame/SIF_Metadata/LifeCycle/TimeElements/TimeElement | NAPCodeFrame/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | NAPCodeFrame/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | NAPCodeFrame/SIF_ExtendedElements/SIF_ExtendedElement | NAPEventStudentLink/TestDisruptionList/TestDisruption | NAPEventStudentLink/Adjustment/PNPCodeList/PNPCode | NAPEventStudentLink/SIF_Metadata/TimeElements/TimeElement | NAPEventStudentLink/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | NAPEventStudentLink/SIF_Metadata/LifeCycle/Created/Creators/Creator | NAPEventStudentLink/SIF_Metadata/LifeCycle/ModificationHistory/Modified | NAPEventStudentLink/SIF_Metadata/LifeCycle/TimeElements/TimeElement | NAPEventStudentLink/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | NAPEventStudentLink/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | NAPEventStudentLink/SIF_ExtendedElements/SIF_ExtendedElement | NAPStudentResponseSet/DomainScore/PlausibleScaledValueList/PlausibleScaledValue | NAPStudentResponseSet/TestletList/Testlet | NAPStudentResponseSet/TestletList/Testlet/ItemResponseList/ItemResponse | NAPStudentResponseSet/TestletList/Testlet/ItemResponseList/ItemResponse/SubscoreList/Subscore | NAPStudentResponseSet/SIF_Metadata/TimeElements/TimeElement | NAPStudentResponseSet/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | NAPStudentResponseSet/SIF_Metadata/LifeCycle/Created/Creators/Creator | NAPStudentResponseSet/SIF_Metadata/LifeCycle/ModificationHistory/Modified | NAPStudentResponseSet/SIF_Metadata/LifeCycle/TimeElements/TimeElement | NAPStudentResponseSet/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | NAPStudentResponseSet/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | NAPStudentResponseSet/SIF_ExtendedElements/SIF_ExtendedElement | NAPTest/SIF_Metadata/TimeElements/TimeElement | NAPTest/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | NAPTest/SIF_Metadata/LifeCycle/Created/Creators/Creator | NAPTest/SIF_Metadata/LifeCycle/ModificationHistory/Modified | NAPTest/SIF_Metadata/LifeCycle/TimeElements/TimeElement | NAPTest/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | NAPTest/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | NAPTest/SIF_ExtendedElements/SIF_ExtendedElement | NAPTestItem/TestItemContent/ItemSubstitutedForList/SubstituteItem | NAPTestItem/TestItemContent/ItemSubstitutedForList/SubstituteItem/PNPCodeList/PNPCode | NAPTestItem/TestItemContent/ContentDescriptionList/ContentDescription | NAPTestItem/TestItemContent/StimulusList/Stimulus | NAPTestItem/TestItemContent/NAPWritingRubricList/NAPWritingRubric | NAPTestItem/TestItemContent/NAPWritingRubricList/NAPWritingRubric/ScoreList/Score | NAPTestItem/TestItemContent/NAPWritingRubricList/NAPWritingRubric/ScoreList/Score/ScoreDescriptionList/ScoreDescription | NAPTestItem/SIF_Metadata/TimeElements/TimeElement | NAPTestItem/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | NAPTestItem/SIF_Metadata/LifeCycle/Created/Creators/Creator | NAPTestItem/SIF_Metadata/LifeCycle/ModificationHistory/Modified | NAPTestItem/SIF_Metadata/LifeCycle/TimeElements/TimeElement | NAPTestItem/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | NAPTestItem/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | NAPTestItem/SIF_ExtendedElements/SIF_ExtendedElement | NAPTestScoreSummary/SIF_Metadata/TimeElements/TimeElement | NAPTestScoreSummary/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | NAPTestScoreSummary/SIF_Metadata/LifeCycle/Created/Creators/Creator | NAPTestScoreSummary/SIF_Metadata/LifeCycle/ModificationHistory/Modified | NAPTestScoreSummary/SIF_Metadata/LifeCycle/TimeElements/TimeElement | NAPTestScoreSummary/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | NAPTestScoreSummary/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | NAPTestScoreSummary/SIF_ExtendedElements/SIF_ExtendedElement | NAPTestlet/TestItemList/TestItem | NAPTestlet/SIF_Metadata/TimeElements/TimeElement | NAPTestlet/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | NAPTestlet/SIF_Metadata/LifeCycle/Created/Creators/Creator | NAPTestlet/SIF_Metadata/LifeCycle/ModificationHistory/Modified | NAPTestlet/SIF_Metadata/LifeCycle/TimeElements/TimeElement | NAPTestlet/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | NAPTestlet/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | NAPTestlet/SIF_ExtendedElements/SIF_ExtendedElement | PaymentReceipt/FinancialAccountRefIdList/FinancialAccountRefId | PaymentReceipt/SIF_Metadata/TimeElements/TimeElement | PaymentReceipt/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | PaymentReceipt/SIF_Metadata/LifeCycle/Created/Creators/Creator | PaymentReceipt/SIF_Metadata/LifeCycle/ModificationHistory/Modified | PaymentReceipt/SIF_Metadata/LifeCycle/TimeElements/TimeElement | PaymentReceipt/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | PaymentReceipt/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | PaymentReceipt/SIF_ExtendedElements/SIF_ExtendedElement | PurchaseOrder/PurchasingItems/PurchasingItem | PurchaseOrder/PurchasingItems/PurchasingItem/ExpenseAccounts/ExpenseAccount | PurchaseOrder/SIF_Metadata/TimeElements/TimeElement | PurchaseOrder/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | PurchaseOrder/SIF_Metadata/LifeCycle/Created/Creators/Creator | PurchaseOrder/SIF_Metadata/LifeCycle/ModificationHistory/Modified | PurchaseOrder/SIF_Metadata/LifeCycle/TimeElements/TimeElement | PurchaseOrder/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | PurchaseOrder/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | PurchaseOrder/SIF_ExtendedElements/SIF_ExtendedElement | VendorInfo/ContactInfo/Address/StatisticalAreas/StatisticalArea | VendorInfo/ContactInfo/EmailList/Email | VendorInfo/ContactInfo/PhoneNumberList/PhoneNumber | VendorInfo/SIF_Metadata/TimeElements/TimeElement | VendorInfo/SIF_Metadata/TimeElements/TimeElement/SpanGaps/SpanGap | VendorInfo/SIF_Metadata/LifeCycle/Created/Creators/Creator | VendorInfo/SIF_Metadata/LifeCycle/ModificationHistory/Modified | VendorInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement | VendorInfo/SIF_Metadata/LifeCycle/TimeElements/TimeElement/SpanGaps/SpanGap | VendorInfo/SIF_Metadata/EducationFilter/LearningStandardItems/LearningStandardItemRefId | VendorInfo/SIF_ExtendedElements/SIF_ExtendedElement" mode="detect">
  <xsl:if test="count(preceding-sibling::*) = 0">
      <xsl:text>"</xsl:text><xsl:value-of select="name()"/><xsl:text>" : [</xsl:text>
    </xsl:if>
    <xsl:choose>
      <xsl:when test="count(./child::*) > 0 or count(@*) > 0">
        <xsl:apply-templates select="." mode="obj-content" />
      </xsl:when>
      <xsl:when test="count(./child::*) = 0">
        <xsl:apply-templates select="." mode="value"/>
      </xsl:when>
    </xsl:choose>
    <xsl:if test="count(following-sibling::*) &gt; 0">, </xsl:if>
    <xsl:if test="count(following-sibling::*) = 0"><xsl:text>]</xsl:text></xsl:if>
  </xsl:template>

  <xsl:template match="*" mode="obj-content">
    <xsl:text>{</xsl:text>
    <xsl:apply-templates select="@*" mode="attr" />
    <xsl:if test="count(@*) &gt; 0 and (count(child::*) &gt; 0 or text())">, </xsl:if>
    <xsl:apply-templates select="./*" mode="detect" />
    <xsl:if test="count(child::*) = 0 and text() and not(@*)">
      <xsl:text>"</xsl:text><xsl:value-of select="name()"/>" : <xsl:apply-templates select="." mode="value"/>
    </xsl:if>
    <xsl:if test="count(child::*) = 0 and text() and @*">
      <xsl:text>"value" : </xsl:text><xsl:apply-templates select="." mode="value"/>
    </xsl:if>
    <xsl:text>}</xsl:text>
    <xsl:if test="position() &lt; last()">, </xsl:if>
  </xsl:template>

  <!-- simple content with attribute -->
  <xsl:template match="Activity/SubjectArea/OtherCodeList/OtherCode | Activity/SourceObjects/SourceObject | Activity/ActivityTime/Duration | Activity/SIF_ExtendedElements/SIF_ExtendedElement | AggregateCharacteristicInfo/SIF_ExtendedElements/SIF_ExtendedElement | AggregateStatisticFact/SIF_ExtendedElements/SIF_ExtendedElement | AggregateStatisticInfo/CalculationRule | AggregateStatisticInfo/ExclusionRules/ExclusionRule | AggregateStatisticInfo/Location/LocationRefId | AggregateStatisticInfo/SIF_ExtendedElements/SIF_ExtendedElement | CalendarDate/CalendarDateType/OtherCodeList/OtherCode | CalendarDate/SIF_ExtendedElements/SIF_ExtendedElement | CalendarSummary/SIF_ExtendedElements/SIF_ExtendedElement | EquipmentInfo/SIF_RefId | EquipmentInfo/SIF_ExtendedElements/SIF_ExtendedElement | GradingAssignment/SIF_ExtendedElements/SIF_ExtendedElement | GradingAssignmentScore/SIF_ExtendedElements/SIF_ExtendedElement | Identity/SIF_RefId | Identity/IdentityAssertions/IdentityAssertion | Identity/PasswordList/Password | Identity/SIF_ExtendedElements/SIF_ExtendedElement | LEAInfo/EducationAgencyType/OtherCodeList/OtherCode | LEAInfo/LEAContactList/LEAContact/ContactInfo/Address/StatisticalAreas/StatisticalArea | LEAInfo/LEAContactList/LEAContact/ContactInfo/EmailList/Email | LEAInfo/AddressList/Address/StatisticalAreas/StatisticalArea | LEAInfo/SIF_ExtendedElements/SIF_ExtendedElement | LearningResource/Contacts/Contact/Address/StatisticalAreas/StatisticalArea | LearningResource/Contacts/Contact/Email | LearningResource/Location | LearningResource/SubjectAreas/ACStrandSubjectArea/SubjectArea/OtherCodeList/OtherCode | LearningResource/Components/Component/AssociatedObjects/AssociatedObject | LearningResource/SIF_ExtendedElements/SIF_ExtendedElement | LearningStandardDocument/RichDescription/XMLData | LearningStandardDocument/RichDescription/TextData | LearningStandardDocument/RichDescription/BinaryData | LearningStandardDocument/SubjectAreas/ACStrandSubjectArea/SubjectArea/OtherCodeList/OtherCode | LearningStandardDocument/SIF_ExtendedElements/SIF_ExtendedElement | LearningStandardItem/Resources/LearningResourceRefId | LearningStandardItem/ACStrandSubjectArea/SubjectArea/OtherCodeList/OtherCode | LearningStandardItem/StandardIdentifier/ACStrandSubjectArea/SubjectArea/OtherCodeList/OtherCode | LearningStandardItem/RelatedLearningStandardItems/LearningStandardItemRefId | LearningStandardItem/SIF_ExtendedElements/SIF_ExtendedElement | MarkValueInfo/SIF_ExtendedElements/SIF_ExtendedElement | PersonPicture/ParentObjectRefId | PersonPicture/PictureSource | PersonPicture/SIF_ExtendedElements/SIF_ExtendedElement | PersonPrivacyObligation/SIF_ExtendedElements/SIF_ExtendedElement | PersonalisedPlan/SIF_ExtendedElements/SIF_ExtendedElement | ReportAuthorityInfo/ContactInfo/Address/StatisticalAreas/StatisticalArea | ReportAuthorityInfo/ContactInfo/EmailList/Email | ReportAuthorityInfo/Address/StatisticalAreas/StatisticalArea | ReportAuthorityInfo/SIF_ExtendedElements/SIF_ExtendedElement | ResourceBooking/ResourceRefId | ResourceBooking/SIF_ExtendedElements/SIF_ExtendedElement | ResourceUsage/ResourceReportLineList/ResourceReportLine/SIF_RefId | ResourceUsage/ResourceReportLineList/ResourceReportLine/CurrentCost | ResourceUsage/SIF_ExtendedElements/SIF_ExtendedElement | RoomInfo/SIF_ExtendedElements/SIF_ExtendedElement | ScheduledActivity/AddressList/Address/StatisticalAreas/StatisticalArea | ScheduledActivity/Override | ScheduledActivity/SIF_ExtendedElements/SIF_ExtendedElement | SchoolCourseInfo/SubjectAreaList/SubjectArea/OtherCodeList/OtherCode | SchoolCourseInfo/SIF_ExtendedElements/SIF_ExtendedElement | SchoolInfo/OtherIdList/OtherId | SchoolInfo/OtherLEA | SchoolInfo/SchoolEmailList/Email | SchoolInfo/PrincipalInfo/EmailList/Email | SchoolInfo/SchoolContactList/SchoolContact/ContactInfo/Address/StatisticalAreas/StatisticalArea | SchoolInfo/SchoolContactList/SchoolContact/ContactInfo/EmailList/Email | SchoolInfo/AddressList/Address/StatisticalAreas/StatisticalArea | SchoolInfo/SIF_ExtendedElements/SIF_ExtendedElement | SchoolPrograms/SchoolProgramList/Program/OtherCodeList/OtherCode | SchoolPrograms/SIF_ExtendedElements/SIF_ExtendedElement | SectionInfo/MediumOfInstruction/OtherCodeList/OtherCode | SectionInfo/LanguageOfInstruction/OtherCodeList/OtherCode | SectionInfo/LocationOfInstruction/OtherCodeList/OtherCode | SectionInfo/SchoolCourseInfoOverride/SubjectArea/OtherCodeList/OtherCode | SectionInfo/SIF_ExtendedElements/SIF_ExtendedElement | SessionInfo/SIF_ExtendedElements/SIF_ExtendedElement | StaffAssignment/StaffActivity/OtherCodeList/OtherCode | StaffAssignment/SIF_ExtendedElements/SIF_ExtendedElement | StaffPersonal/ElectronicIdList/ElectronicId | StaffPersonal/OtherIdList/OtherId | StaffPersonal/PersonInfo/Demographics/EnglishProficiency/OtherCodeList/OtherCode | StaffPersonal/PersonInfo/Demographics/LanguageList/Language/OtherCodeList/OtherCode | StaffPersonal/PersonInfo/Demographics/DwellingArrangement/OtherCodeList/OtherCode | StaffPersonal/PersonInfo/Demographics/Religion/OtherCodeList/OtherCode | StaffPersonal/PersonInfo/AddressList/Address/StatisticalAreas/StatisticalArea | StaffPersonal/PersonInfo/EmailList/Email | StaffPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/AddressList/Address/StatisticalAreas/StatisticalArea | StaffPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/EmailList/Email | StaffPersonal/SIF_ExtendedElements/SIF_ExtendedElement | StudentActivityInfo/StudentActivityType/OtherCodeList/OtherCode | StudentActivityInfo/Location/LocationRefId | StudentActivityInfo/SIF_ExtendedElements/SIF_ExtendedElement | StudentActivityParticipation/SIF_ExtendedElements/SIF_ExtendedElement | StudentAttendanceSummary/SIF_ExtendedElements/SIF_ExtendedElement | StudentAttendanceTimeList/AttendanceTimes/AttendanceTime/AttendanceCode/OtherCodeList/OtherCode | StudentAttendanceTimeList/PeriodAttendances/PeriodAttendance/AttendanceCode/OtherCodeList/OtherCode | StudentAttendanceTimeList/SIF_ExtendedElements/SIF_ExtendedElement | StudentContactPersonal/OtherIdList/OtherId | StudentContactPersonal/PersonInfo/Demographics/EnglishProficiency/OtherCodeList/OtherCode | StudentContactPersonal/PersonInfo/Demographics/LanguageList/Language/OtherCodeList/OtherCode | StudentContactPersonal/PersonInfo/Demographics/DwellingArrangement/OtherCodeList/OtherCode | StudentContactPersonal/PersonInfo/Demographics/Religion/OtherCodeList/OtherCode | StudentContactPersonal/PersonInfo/AddressList/Address/StatisticalAreas/StatisticalArea | StudentContactPersonal/PersonInfo/EmailList/Email | StudentContactPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/AddressList/Address/StatisticalAreas/StatisticalArea | StudentContactPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/EmailList/Email | StudentContactPersonal/SIF_ExtendedElements/SIF_ExtendedElement | StudentContactRelationship/Relationship/OtherCodeList/OtherCode | StudentContactRelationship/SIF_ExtendedElements/SIF_ExtendedElement | StudentDailyAttendance/AttendanceCode/OtherCodeList/OtherCode | StudentDailyAttendance/SIF_ExtendedElements/SIF_ExtendedElement | StudentGrade/LearningArea/SubjectArea/OtherCodeList/OtherCode | StudentGrade/SIF_ExtendedElements/SIF_ExtendedElement | StudentParticipation/ProgramFundingSources/ProgramFundingSource/OtherCodeList/OtherCode | StudentParticipation/ManagingSchool | StudentParticipation/ReferralSource/OtherCodeList/OtherCode | StudentParticipation/ProgramStatus/OtherCodeList/OtherCode | StudentParticipation/ProgramAvailability/OtherCodeList/OtherCode | StudentParticipation/SIF_ExtendedElements/SIF_ExtendedElement | StudentPeriodAttendance/AttendanceCode/OtherCodeList/OtherCode | StudentPeriodAttendance/SIF_ExtendedElements/SIF_ExtendedElement | StudentPersonal/AlertMessages/AlertMessage | StudentPersonal/MedicalAlertMessages/MedicalAlertMessage | StudentPersonal/ElectronicIdList/ElectronicId | StudentPersonal/OtherIdList/OtherId | StudentPersonal/PersonInfo/Demographics/EnglishProficiency/OtherCodeList/OtherCode | StudentPersonal/PersonInfo/Demographics/LanguageList/Language/OtherCodeList/OtherCode | StudentPersonal/PersonInfo/Demographics/DwellingArrangement/OtherCodeList/OtherCode | StudentPersonal/PersonInfo/Demographics/Religion/OtherCodeList/OtherCode | StudentPersonal/PersonInfo/AddressList/Address/StatisticalAreas/StatisticalArea | StudentPersonal/PersonInfo/EmailList/Email | StudentPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/AddressList/Address/StatisticalAreas/StatisticalArea | StudentPersonal/PersonInfo/HouseholdContactInfoList/HouseholdContactInfo/EmailList/Email | StudentPersonal/SIF_ExtendedElements/SIF_ExtendedElement | StudentSchoolEnrollment/EntryType/OtherCodeList/OtherCode | StudentSchoolEnrollment/Homeroom | StudentSchoolEnrollment/Advisor | StudentSchoolEnrollment/Counselor | StudentSchoolEnrollment/Calendar | StudentSchoolEnrollment/ExitStatus/OtherCodeList/OtherCode | StudentSchoolEnrollment/ExitType/OtherCodeList/OtherCode | StudentSchoolEnrollment/CatchmentStatus/OtherCodeList/OtherCode | StudentSchoolEnrollment/StudentSubjectChoiceList/StudentSubjectChoice/StudyDescription/OtherCodeList/OtherCode | StudentSchoolEnrollment/SIF_ExtendedElements/SIF_ExtendedElement | StudentSectionEnrollment/SIF_ExtendedElements/SIF_ExtendedElement | SystemRole/SIF_RefId | SystemRole/SystemContextList/SystemContext/RoleList/Role/RoleScopeList/RoleScope/RoleScopeRefId | SystemRole/SIF_ExtendedElements/SIF_ExtendedElement | TeachingGroup/SIF_ExtendedElements/SIF_ExtendedElement | TermInfo/SIF_ExtendedElements/SIF_ExtendedElement | TimeTable/SIF_ExtendedElements/SIF_ExtendedElement | TimeTableCell/SIF_ExtendedElements/SIF_ExtendedElement | TimeTableSubject/OtherCodeList/OtherCode | TimeTableSubject/SIF_ExtendedElements/SIF_ExtendedElement | WellbeingAlert/SIF_ExtendedElements/SIF_ExtendedElement | WellbeingAppeal/SIF_ExtendedElements/SIF_ExtendedElement | WellbeingCharacteristic/SIF_ExtendedElements/SIF_ExtendedElement | WellbeingEvent/PersonInvolvementList/PersonInvolvement/PersonRefId | WellbeingEvent/SIF_ExtendedElements/SIF_ExtendedElement | WellbeingResponse/PersonInvolvementList/PersonInvolvement/PersonRefId | WellbeingResponse/SIF_ExtendedElements/SIF_ExtendedElement | AGStatusReport/SIF_ExtendedElements/SIF_ExtendedElement | ChargedLocationInfo/AddressList/Address/StatisticalAreas/StatisticalArea | ChargedLocationInfo/SIF_ExtendedElements/SIF_ExtendedElement | Debtor/BilledEntity | Debtor/AddressList/Address/StatisticalAreas/StatisticalArea | Debtor/SIF_ExtendedElements/SIF_ExtendedElement | FQReporting/EntityContact/Address/StatisticalAreas/StatisticalArea | FQReporting/EntityContact/Email | FQReporting/SIF_ExtendedElements/SIF_ExtendedElement | FinancialAccount/SIF_ExtendedElements/SIF_ExtendedElement | Invoice/InvoicedEntity | Invoice/BilledAmount | Invoice/NetAmount | Invoice/TaxAmount | Invoice/PurchasingItems/PurchasingItem/UnitCost | Invoice/PurchasingItems/PurchasingItem/TotalCost | Invoice/PurchasingItems/PurchasingItem/ExpenseAccounts/ExpenseAccount/Amount | Invoice/SIF_ExtendedElements/SIF_ExtendedElement | Journal/OriginatingTransactionRefId | Journal/Amount | Journal/SIF_ExtendedElements/SIF_ExtendedElement | NAPCodeFrame/SIF_ExtendedElements/SIF_ExtendedElement | NAPEventStudentLink/SIF_ExtendedElements/SIF_ExtendedElement | NAPStudentResponseSet/SIF_ExtendedElements/SIF_ExtendedElement | NAPTest/SIF_ExtendedElements/SIF_ExtendedElement | NAPTestItem/SIF_ExtendedElements/SIF_ExtendedElement | NAPTestScoreSummary/SIF_ExtendedElements/SIF_ExtendedElement | NAPTestlet/SIF_ExtendedElements/SIF_ExtendedElement | PaymentReceipt/TransactionAmount | PaymentReceipt/TaxAmount | PaymentReceipt/SIF_ExtendedElements/SIF_ExtendedElement | PurchaseOrder/PurchasingItems/PurchasingItem/UnitCost | PurchaseOrder/PurchasingItems/PurchasingItem/TotalCost | PurchaseOrder/PurchasingItems/PurchasingItem/ExpenseAccounts/ExpenseAccount/Amount | PurchaseOrder/TaxAmount | PurchaseOrder/TotalAmount | PurchaseOrder/SIF_ExtendedElements/SIF_ExtendedElement | VendorInfo/ContactInfo/Address/StatisticalAreas/StatisticalArea | VendorInfo/ContactInfo/EmailList/Email | VendorInfo/SIF_ExtendedElements/SIF_ExtendedElement" mode="obj-content">
    <xsl:text>{</xsl:text>
    <xsl:apply-templates select="@*" mode="attr" />
    <xsl:if test="count(@*) &gt; 0 and (count(child::*) &gt; 0 or text())">, </xsl:if>
    <xsl:apply-templates select="./*" mode="detect" />
    <xsl:if test="count(child::*) = 0 and text()">
      <xsl:text>"value" : </xsl:text><xsl:apply-templates select="." mode="value"/>
    </xsl:if>
    <xsl:text>}</xsl:text>
    <xsl:if test="position() &lt; last()">, </xsl:if>
  </xsl:template>

  <xsl:template match="@*" mode="attr">
    <xsl:text>"</xsl:text><xsl:value-of select="name()"/>" : <xsl:apply-templates select="." mode="attrvalue"/>
    <xsl:if test="position() &lt; last()">, </xsl:if>
  </xsl:template>

  <!-- https://github.com/bramstein/xsltjson/blob/master/conf/xml-to-jsonml.xsl -->
  <json:search name="string">
		<json:replace src="\" dst="\\"/>
		<json:replace src="&quot;" dst="\&quot;"/>
		<json:replace src="&#xA;" dst="\n"/>
		<json:replace src="&#xD;" dst="\r"/>
		<json:replace src="&#x9;" dst="\t"/>
		<json:replace src="\n" dst="\n"/>
		<json:replace src="\r" dst="\r"/>
		<json:replace src="\t" dst="\t"/>
  </json:search>

  <xsl:template name="replace-string">
		<xsl:param name="input"/>
		<xsl:param name="src"/>
		<xsl:param name="dst"/>
		<xsl:choose>
			<xsl:when test="contains($input, $src)">
				<xsl:value-of select="concat(substring-before($input, $src), $dst)"/>
				<xsl:call-template name="replace-string">
					<xsl:with-param name="input" select="substring-after($input, $src)"/>
					<xsl:with-param name="src" select="$src"/>
					<xsl:with-param name="dst" select="$dst"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$input"/>
			</xsl:otherwise>
		</xsl:choose>
  </xsl:template>

  <xsl:template name="encode">
		<xsl:param name="input"/>
		<xsl:param name="index">1</xsl:param>

		<xsl:variable name="text">
			<xsl:call-template name="replace-string">
				<xsl:with-param name="input" select="$input"/>
				<xsl:with-param name="src" select="document('')//json:search/json:replace[$index]/@src"/>
				<xsl:with-param name="dst" select="document('')//json:search/json:replace[$index]/@dst"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="$index &lt; count(document('')//json:search/json:replace)">
				<xsl:call-template name="encode">
					<xsl:with-param name="input" select="$text"/>
					<xsl:with-param name="index" select="$index + 1"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$text"/>
			</xsl:otherwise>
		</xsl:choose>
  </xsl:template>

  <xsl:template name="encode-value">
                <xsl:param name="value"/>
                <xsl:choose>
                        <xsl:when test="normalize-space($value) != $value">
                                <xsl:call-template name="encode">
                                        <xsl:with-param name="input" select="$value"/>
                                </xsl:call-template>
                        </xsl:when>
                        <xsl:otherwise>
                                <xsl:value-of select="$value"/>
                        </xsl:otherwise>
                </xsl:choose>
  </xsl:template>

  <xsl:template match="node/@TEXT | text()" name="removeBreaks" priority="10">
    <xsl:call-template name="encode-value">
      <xsl:with-param name="value" select="." />
    </xsl:call-template>
  </xsl:template>

</xsl:stylesheet>